/*****************************************************************************
 *  Rohde&Schwarz SFC Compact Modulator instrument driver     
 *  VXIpnp Style Instrument Driver
 *  Original Release: 06/2011
 *  By: 
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *****************************************************************************/

#ifndef __RSSFC_HEADER
#define __RSSFC_HEADER

#include "rsidr_core.h"
#include <stdlib.h>
#include "rssfc_attributes.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/


/* Class Driver Identification */

#define RSSFC_CLASS_DRIVER_DESCRIPTION           ""
#define RSSFC_CLASS_DRIVER_PREFIX                ""
#define RSSFC_CLASS_DRIVER_VENDOR                ""
#define RSSFC_CLASS_DRIVER_REVISION              ""
#define RSSFC_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSSFC_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSSFC_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSSFC_SPECIFIC_DRIVER_PREFIX             "rssfc"
#define RSSFC_SPECIFIC_DRIVER_LOCATOR            ""
#define RSSFC_SPECIFIC_DRIVER_VENDOR             ""
#define RSSFC_MAJOR_VERSION                      2L    /* Instrument driver major version          */
#define RSSFC_MINOR_VERSION                      80L   /* Instrument driver minor version          */
#define RSSFC_MINOR_MINOR_VERSION                3L    /* Instrument driver minor minor version    */

/* Driver Capabilities */          

#define RSSFC_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSSFC_GROUP_CAPABILITIES                 ""
#define RSSFC_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSSFC_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSSFC_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSSFC_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSSFC_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSSFC_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSSFC_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSSFC_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSSFC_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSSFC_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSSFC_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSSFC_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSSFC_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSSFC_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSSFC_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSSFC_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSSFC_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSSFC_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSSFC_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSSFC_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSSFC_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSSFC_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSSFC_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSSFC_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSSFC_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSSFC_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSSFC_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSSFC_ATTR_FREQ_CW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSSFC_ATTR_FREQ_ACT_CENTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSSFC_ATTR_FREQ_CHANNEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSSFC_ATTR_FREQ_CHANNEL_NAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSSFC_ATTR_FREQ_CHANNEL_TABLE_SELECT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSSFC_ATTR_FREQ_CHANNEL_TABLE_STORE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSSFC_ATTR_FREQ_CHANNEL_TABLE_DELETE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSSFC_ATTR_FREQ_VSB_REF_POINT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSSFC_ATTR_POW_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSSFC_ATTR_RFOUT_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSSFC_ATTR_POW_USER_LIMIT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSSFC_ATTR_POW_PEAK_ENVELOPE_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSSFC_ATTR_RFOUT_AMODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSSFC_ATTR_RFOUT_ATT_MIN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSSFC_ATTR_RFOUT_ATT_MAX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSSFC_ATTR_POW_LEV_UNIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSSFC_ATTR_MOD_DM_MODULATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSSFC_ATTR_MOD_DM_SIGNAL_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSSFC_ATTR_MOD_DM_TRANSMISSION_STANDARD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSSFC_ATTR_MOD_DM_ATV_TRANSMISSION_STANDARD                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSSFC_ATTR_MOD_DM_SPECTRUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSSFC_ATTR_MOD_DM_AUDIO_STANDARD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSSFC_ATTR_MOD_DM_IQ_SWAP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSSFC_ATTR_MOD_DIGITAL_IN_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSSFC_ATTR_MOD_DIGITAL_IQ_INPUT_RMS_VAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSSFC_ATTR_MOD_DIGITAL_IQ_INPUT_PEAK_VAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSSFC_ATTR_MOD_DIGITAL_IQ_INPUT_REFRESH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSSFC_ATTR_MODULATION_DIGITAL_IQ_INPUT_SYMBOL_RATE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSSFC_ATTR_IQC_DVBT_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSSFC_ATTR_IQC_DVBT_SOUR_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSSFC_ATTR_IQC_DVBT_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSSFC_ATTR_IQC_DVBT_INP_LOW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSSFC_ATTR_IQC_DVBT_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSSFC_ATTR_IQC_DVBT_STUF_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSSFC_ATTR_IQC_DVBT_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSSFC_ATTR_IQC_DVBT_TEST_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSSFC_ATTR_IQC_DVBT_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSSFC_ATTR_IQC_DVBT_PACKET_LENGTH_LOW                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSSFC_ATTR_IQC_DVBT_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSSFC_ATTR_IQC_DVBT_MAX_USEFUL_DATA_RATE_LOW                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSSFC_ATTR_IQC_DVBT_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSSFC_ATTR_IQC_DVBT_MEASURED_DATA_RATE_LOW                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSSFC_ATTR_IQC_DVBT_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSSFC_ATTR_IQC_DVBT_USEFUL_DATA_RATE_LOW                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSSFC_ATTR_IQC_DVBT_CHAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSSFC_ATTR_IQC_DVBT_USED_RESULT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSSFC_ATTR_IQC_DVBT_FFT_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSSFC_ATTR_IQC_DVBT_GUAR_INT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSSFC_ATTR_IQC_DVBT_HIER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSSFC_ATTR_IQC_DVBT_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSSFC_ATTR_IQC_DVBT_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSSFC_ATTR_IQC_DVBT_RATE_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSSFC_ATTR_IQC_DVBT_DVHS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSSFC_ATTR_IQC_DVBT_DVBH_SYMB                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSSFC_ATTR_IQC_DVBT_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSSFC_ATTR_IQC_DVBT_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSSFC_ATTR_IQC_DVBT_REED_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSSFC_ATTR_IQC_DVBT_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSSFC_ATTR_IQC_DVBT_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSSFC_ATTR_IQC_DVBT_CELL_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSSFC_ATTR_IQC_DVBT_TPSR_STAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSSFC_ATTR_IQC_DVBT_TPSR_VAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSSFC_ATTR_IQC_DVBT_TIM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSSFC_ATTR_IQC_DVBT_TIM_LOW                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSSFC_ATTR_IQC_DVBT_MPEF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSSFC_ATTR_IQC_DVBT_MPEF_LOW                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSSFC_ATTR_DVBT_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSSFC_ATTR_IQC_DVBC_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSSFC_ATTR_IQC_DVBC_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSSFC_ATTR_IQC_DVBC_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSSFC_ATTR_IQC_DVBC_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSSFC_ATTR_IQC_DVBC_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSSFC_ATTR_IQC_DVBC_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSSFC_ATTR_IQC_DVBC_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSSFC_ATTR_IQC_DVBC_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSSFC_ATTR_IQC_DVBC_SYMB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSSFC_ATTR_IQC_DVBC_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSSFC_ATTR_IQC_DVBC_ROLL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSSFC_ATTR_IQC_DVBC_SETT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSSFC_ATTR_IQC_DVBC_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSSFC_ATTR_IQC_DVBC_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSSFC_ATTR_IQC_DVBC_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSSFC_ATTR_DVBC_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSSFC_ATTR_IQC_DTMB_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSSFC_ATTR_IQC_DTMB_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSSFC_ATTR_IQC_DTMB_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSSFC_ATTR_IQC_DTMB_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSSFC_ATTR_IQC_DTMB_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSSFC_ATTR_IQC_DTMB_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSSFC_ATTR_IQC_DTMB_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSSFC_ATTR_IQC_DTMB_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSSFC_ATTR_IQC_DTMB_NETW                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSSFC_ATTR_IQC_DTMB_CODING_SINGLE_CARRIER_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSSFC_ATTR_IQC_DTMB_CODING_DUAL_PILOT_TONE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSSFC_ATTR_IQC_DTMB_CODING_CONTROL_FRAMES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSSFC_ATTR_IQC_DTMB_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSSFC_ATTR_IQC_DTMB_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSSFC_ATTR_IQC_DTMB_GUARD_INTERVAL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSSFC_ATTR_IQC_DTMB_SPECIAL_GUARD_INTERVAL_PN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSSFC_ATTR_IQC_DTMB_TIME_INTERLEAVER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSSFC_ATTR_IQC_DTMB_CHAN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSSFC_ATTR_IQC_DTMB_DEL_ADD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSSFC_ATTR_IQC_DTMB_LOCAL_DEL_ADD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSSFC_ATTR_IQC_DTMB_LOCAL_DEL_MAX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSSFC_ATTR_IQC_DTMB_SIGNAL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSSFC_ATTR_IQC_DTMB_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSSFC_ATTR_IQC_DTMB_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSSFC_ATTR_DTMB_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSSFC_ATTR_IQC_DVBS_SOUR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSSFC_ATTR_IQC_DVBS_INP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSSFC_ATTR_IQC_DVBS_STUF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSSFC_ATTR_IQC_DVBS_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSSFC_ATTR_IQC_DVBS_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSSFC_ATTR_IQC_DVBS_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSSFC_ATTR_IQC_DVBS_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSSFC_ATTR_IQC_DVBS_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSSFC_ATTR_IQC_DVBS_SYMB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSSFC_ATTR_IQC_DVBS_CONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSSFC_ATTR_IQC_DVBS_ROLL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSSFC_ATTR_IQC_DVBS_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSSFC_ATTR_IQC_DVBS_SETT_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSSFC_ATTR_IQC_DVBS_REED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSSFC_ATTR_IQC_DVBS_TSP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSSFC_ATTR_IQC_DVBS_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSSFC_ATTR_DVBS_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSSFC_ATTR_DVBS2_INPUT_SIGNAL_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSSFC_ATTR_DVBS2_INPUT_SIGNAL_INPUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSSFC_ATTR_DVBS2_INPUT_SIGNAL_STUFFING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSSFC_ATTR_DVBS2_INPUT_SIGNAL_TEST_SIGNAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSSFC_ATTR_READ_DVBS2_PACKET_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSSFC_ATTR_READ_DVBS2_MEASURED_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSSFC_ATTR_READ_DVBS2_MAX_USEFUL_DATA_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSSFC_ATTR_READ_DVBS2_USEFUL_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSSFC_ATTR_DVBS2_CODING_SYMBOL_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSSFC_ATTR_DVBS2_CODING_CONSTELLATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSSFC_ATTR_DVBS2_CODING_FEC_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSSFC_ATTR_DVBS2_CODING_PILOTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSSFC_ATTR_DVBS2_CODING_ROLL_OFF                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSSFC_ATTR_DVBS2_CODING_CODE_RATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSSFC_ATTR_DVBS2_SETTINGS_TEST_TS_PACKET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSSFC_ATTR_DVBS2_SETTINGS_PRBS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSSFC_ATTR_DVBS2_SETTINGS_PAYLOAD_TEST_STUFF                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSSFC_ATTR_TDMB_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSSFC_ATTR_TDMB_ETI_INPUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSSFC_ATTR_TDMB_NUMBER_OF_STREAMS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSSFC_ATTR_TDMB_MODE_IDENTITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSSFC_ATTR_TDMB_SCID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSSFC_ATTR_TDMB_PROT_PROFILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSSFC_ATTR_TDMB_PROT_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSSFC_ATTR_TDMB_DATA_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSSFC_ATTR_TDMB_SPECIAL_SETTINGS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSSFC_ATTR_TDMB_TRANSMISSION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSSFC_ATTR_TDMB_SELECT_TRANSMISSION_MODE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSSFC_ATTR_TDMB_PRBS_TESTSIGNAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSSFC_ATTR_TDMB_TESTSIGNAL_SCID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSSFC_ATTR_TDMB_TII                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSSFC_ATTR_TDMB_PRBS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSSFC_ATTR_TDMB_TII_MAIN_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSSFC_ATTR_TDMB_TII_SUB_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSSFC_ATTR_IQC_ISDBT_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSSFC_ATTR_IQC_ISDBT_TEST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSSFC_ATTR_IQC_ISDBT_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSSFC_ATTR_IQC_ISDBT_INPUT_SIGNAL_REMUX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSSFC_ATTR_IQC_ISDBT_INPUT_SIGNAL_STUFFING                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSSFC_ATTR_IQC_ISDBT_INPUT_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSSFC_ATTR_IQC_ISDBT_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSSFC_ATTR_IQC_ISDBT_MEAS_USEFUL_DATA_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSSFC_ATTR_IQC_ISDBT_CODING_SYSTEM                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSSFC_ATTR_IQC_ISDBT_CODING_CONTROL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSSFC_ATTR_IQC_ISDBT_PORTION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSSFC_ATTR_IQC_ISDBT_CONSTELLATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSSFC_ATTR_IQC_ISDBT_SEGMENTS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSSFC_ATTR_IQC_ISDBT_CODE_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSSFC_ATTR_IQC_ISDBT_TIME_INTERLEAVING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSSFC_ATTR_IQC_ISDBT_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSSFC_ATTR_IQC_ISDBT_GUARD_INTERVAL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSSFC_ATTR_IQC_ISDBT_CODING_SUB_CHANNEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSSFC_ATTR_IQC_ISDBT_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSSFC_ATTR_IQC_ISDBT_SPECIAL_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSSFC_ATTR_IQC_ISDBT_AC_DATA1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSSFC_ATTR_IQC_ISDBT_AC_DATA2                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSSFC_ATTR_ISDBT_SPECIAL_SETTINGS_ALERT_BROADCAST                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSSFC_ATTR_ISDBT_SPECIAL_SETTINGS_RESIDUAL_CARRIER_SHIFT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSSFC_ATTR_ISDBT_SPECIAL_SETT_TX_PARAM_SWITCHING_IND                RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSSFC_ATTR_ISDBT_SPECIAL_SETTINGS_TMCC_NEXT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSSFC_ATTR_IQC_ISDBT_TEST_TS_PACKED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSSFC_ATTR_IQC_ISDBT_PRBS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSSFC_ATTR_ISDBT_SETTINGS_PAYLOAD_TEST_STUFF                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSSFC_ATTR_IQC_8VSB_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSSFC_ATTR_IQC_8VSB_INPUT_SIGNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSSFC_ATTR_IQC_8VSB_STUFFING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSSFC_ATTR_IQC_8VSB_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSSFC_ATTR_IQC_8VSB_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSSFC_ATTR_IQC_8VSB_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSSFC_ATTR_IQC_8VSB_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSSFC_ATTR_IQC_8VSB_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSSFC_ATTR_IQC_8VSB_SYMBOL_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSSFC_ATTR_IQC_8VSB_CONSTELLATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSSFC_ATTR_IQC_8VSB_ROLL_OFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSSFC_ATTR_IQC_8VSB_TEST_TS_PACKED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSSFC_ATTR_IQC_8VSB_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSSFC_ATTR_8VSB_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSSFC_ATTR_IQC_J83B_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSSFC_ATTR_IQC_J83B_INPUT_SIGNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSSFC_ATTR_IQC_J83B_STUFFING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSSFC_ATTR_IQC_J83B_PACKET_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSSFC_ATTR_IQC_J83B_MAX_USEFUL_DATA_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSSFC_ATTR_IQC_J83B_MEASURED_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSSFC_ATTR_IQC_J83B_USEFUL_DATA_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSSFC_ATTR_IQC_J83B_TEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSSFC_ATTR_IQC_J83B_SYMBOL_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSSFC_ATTR_IQC_J83B_CONSTELLATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSSFC_ATTR_IQC_J83B_ROLL_OFF                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSSFC_ATTR_IQC_J83B_INTERLEAVER_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSSFC_ATTR_IQC_J83B_SPECIAL_SETTINGS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSSFC_ATTR_IQC_J83B_REED_SOLOMON                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSSFC_ATTR_IQC_J83B_TEST_TS_PACKED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSSFC_ATTR_IQC_J83B_PRBS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSSFC_ATTR_J83B_SETTINGS_PAYLOAD_TEST_STUFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSSFC_ATTR_IQC_DIR_SOUR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSSFC_ATTR_IQC_DIR_INP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSSFC_ATTR_IQC_DIR_STUF                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSSFC_ATTR_IQC_DIR_PACKET_LENGTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSSFC_ATTR_IQC_DIR_REQ_SOURCE_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSSFC_ATTR_IQC_DIR_MAX_USEFUL_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSSFC_ATTR_IQC_DIR_MEASURED_DATA_RATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSSFC_ATTR_IQC_DIR_USEFUL_DATA_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSSFC_ATTR_IQC_DIR_TEST                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSSFC_ATTR_IQC_DIR_SYMB                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSSFC_ATTR_IQC_DIR_CONS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSSFC_ATTR_IQC_DIR_ROLL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSSFC_ATTR_IQC_DIR_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSSFC_ATTR_IQC_DIR_TSP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSSFC_ATTR_IQC_DIR_PRBS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSSFC_ATTR_IQC_MFLO_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSSFC_ATTR_IQC_MFLO_INPUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSSFC_ATTR_IQC_MFLO_MEAS_DATA_RATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_CONTENT_DATA_RATE        RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_CONTROL_CHANNEL_DATA_RATE RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_WIDE_OIS_DATA_RATE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_CONTENT_DATA_RATE       RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_CONTROL_CHANNEL_DATA_RATE RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSSFC_ATTR_READ_MEDIAFLO_INPUT_SIGNAL_LOCAL_OIS_DATA_RATE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSSFC_ATTR_READ_MEDIAFLO_STATUS_SSF_ARRIVAL_TIME                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSSFC_ATTR_READ_MEDIAFLO_STATUS_1PPS_TDM1_ERROR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSSFC_ATTR_READ_MEDIAFLO_STATUS_OUT_OF_FRAME_COUNT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSSFC_ATTR_READ_MEDIAFLO_STATUS_SEQUENCE_ERROR_COUNT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSSFC_ATTR_READ_MEDIAFLO_STATUS_SCHEDULING_ERROR_COUNT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSSFC_ATTR_IQC_MFLO_CHANNEL_BANDWIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSSFC_ATTR_MEDIAFLO_CODING_IFFT_MODE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSSFC_ATTR_MEDIAFLO_CODING_SLOT_TO_INTERLACE_MAPPING                RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSSFC_ATTR_MEDIAFLO_CODING_CYCLIC_PREFIX_LENGTH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSSFC_ATTR_MEDIAFLO_CODING_WIDE_AREA_ID_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSSFC_ATTR_MEDIAFLO_CODING_LOCAL_AREA_ID_VALUE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSSFC_ATTR_MEDIAFLO_CODING_WIDE_MAC_SYMBOLS_FRAME                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 255
#define RSSFC_ATTR_MEDIAFLO_CODING_LOCAL_MAC_SYMBOLS_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSSFC_ATTR_MEDIAFLO_CODING_NETWORK_GEOGRAPHY_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_CONTENT                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_CONTROL_CHANNEL               RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_WIDE_PID_OIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_CONTENT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_CONTROL_CHANNEL              RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_LOCAL_PID_OIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_LOCAL_OIS_INSERTION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_INFRASTRUCTURE_ID                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_LOCAL_TIME_OFFSET                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_DAYLIGHT_SAVINGS_TIME_INDICATOR        RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_POSITION_PILOT_SYMBOLS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TRANSMITTER_ID                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_NUMBER_OF_TRANSMITTERS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_POSITION_ENABLE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 271
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_POSITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_OFFSET_ENABLE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_LATITUDE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_LONGITUDE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSSFC_ATTR_MEDIAFLO_SETTINGS_TX_ALTITUDE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSSFC_ATTR_ATSM_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSSFC_ATTR_ATSM_INPUT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 279
#define RSSFC_ATTR_ATSM_STUFFING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSSFC_ATTR_ATSM_TEST_SIGNAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSSFC_ATTR_READ_ATSM_MEASURED_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSSFC_ATTR_READ_ATSM_USEFUL_DATA_RATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSSFC_ATTR_READ_ATSM_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSSFC_ATTR_READ_ATSM_PACKET_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSSFC_ATTR_ATSM_CONSTELLATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSSFC_ATTR_ATSM_MH_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSSFC_ATTR_ATSM_ROLL_OFF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSSFC_ATTR_ATSM_SYMBOL_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSSFC_ATTR_ATSM_BURY_RATIO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSSFC_ATTR_ATSM_MHE_PID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSSFC_ATTR_ATSM_MARKET_ID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 292
#define RSSFC_ATTR_ATSM_TRANSMITTER_ID                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSSFC_ATTR_ATSM_MTXID_TRANSMISSION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSSFC_ATTR_ATSM_NETWORK_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSSFC_ATTR_ATSM_PAYLOAD_TEST                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSSFC_ATTR_ATSM_PRBS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSSFC_ATTR_ATSM_TEST_TS_PACKET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSSFC_ATTR_ATSM_TX_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSSFC_ATTR_ATSM_WATERMARK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSSFC_ATTR_CMMB_INPUT_SIGNAL_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define RSSFC_ATTR_CMMB_INPUT_SIGNAL_INPUT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 528
#define RSSFC_ATTR_CMMB_INPUT_SIGNAL_STUFFING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 529
#define RSSFC_ATTR_CMMB_INPUT_SIGNAL_NUMBER_OF_SERVICES                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define RSSFC_ATTR_CMMB_INPUT_SIGNAL_TEST_SIGNAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define RSSFC_ATTR_READ_CMMB_MAX_USEFUL_DATA_RATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 532
#define RSSFC_ATTR_READ_CMMB_MEASURED_DATA_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define RSSFC_ATTR_CMMB_CODING_CONTROL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 534
#define RSSFC_ATTR_CMMB_CODING_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSSFC_ATTR_CMMB_CODING_OFDM_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 536
#define RSSFC_ATTR_CMMB_SETTINGS_TRANSMITTER_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSSFC_ATTR_CMMB_SETTINGS_AREA_ID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 538
#define RSSFC_ATTR_CMMB_SETTINGS_PAYLOAD_TEST_SIGNAL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSSFC_ATTR_CMMB_SETTINGS_PRBS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE_STATE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_INTERFACE_INPUT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_PID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_SID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_NUMBER_OF_PLP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_INPUT_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_INPUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 308
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_STUFFING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_MAX_USEF_DR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_MEAS_DR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_USEFUL_DR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_TEST_SIGNAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_RESET_T2_MI_ANALYZER_LOG_FILE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSSFC_ATTR_DVBT2_INPUT_SIGNAL_T2_MI_ANALYZER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_GROUP_ID                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_PLP_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_BB_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_ISSY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_NULL_PACKET_DEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL_A                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_IN_BAND_SIGNAL_B                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_OTHER_IN_BAND_PLP                RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSSFC_ATTR_DVBT2_MODE_STREAM_ADAPT_CM_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 326
#define RSSFC_ATTR_DVBT2_BICM_FEC_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 327
#define RSSFC_ATTR_DVBT2_BICM_CODE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 328
#define RSSFC_ATTR_DVBT2_BICM_CONSTELL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSSFC_ATTR_DVBT2_BICM_CONSTELL_ROTATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSSFC_ATTR_DVBT2_BICM_TIME_INTERL_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSSFC_ATTR_DVBT2_BICM_FRAME_INT_I_JUMP                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSSFC_ATTR_DVBT2_BICM_TIME_INTERL_LENGTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSSFC_ATTR_DVBT2_BICM_FEC_BLOCKS_PER_IF                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSSFC_ATTR_DVBT2_BICM_FEC_MAX_BLOCKS_PER_IF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 335
#define RSSFC_ATTR_DVBT2_FRAMING_CHANNEL_BANDWIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSSFC_ATTR_DVBT2_FRAMING_USED_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSSFC_ATTR_DVBT2_FRAMING_BANDWIDTH_VARIATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSSFC_ATTR_DVBT2_FRAMING_FFT_SIZE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSSFC_ATTR_DVBT2_FRAMING_GUARD_INTERVAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSSFC_ATTR_DVBT2_FRAMING_PILOT_PATTERN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSSFC_ATTR_DVBT2_FRAMING_T2_FRAMES_PER_SUPER_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSSFC_ATTR_DVBT2_FRAMING_OFDM_SYMBOLS_PER_T2_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSSFC_ATTR_DVBT2_FRAMING_DATA_SYMBOLS_PER_T2_FRAME                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSSFC_ATTR_DVBT2_FRAMING_SUBSLICES_PER_T2_FRAME                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_NETWORK_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_PROFILE_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_TRANSMISSION_SYSTEM                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_PEAK_TO_AVRAGE_POWER_RATIO               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_MISO_GROUP_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 577
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_LENGTH           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_TYPE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_INTERVAL         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_FUTURE_EXTENSION_FRAMES_PAYLOAD          RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_TIME_FREQUENCY_SLICING                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L_POST_MODULATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L_REPETITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L1_POST_SCRAMBLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_T2_BASE_LITE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L_POST_EXTENSION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_NUM_AUX_STREAMS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L_RF_SIGNALLING                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L1_SIGNALLING_FREQUENCY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_CELL_ID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_NETWORK_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_L1_T2_VERSION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 365
#define RSSFC_ATTR_DVBT2_T2_SYSTEM_TX_ID_AVAILABILITY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSSFC_ATTR_DVBT2_SFN_PROCESS_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define RSSFC_ATTR_DVBT2_SFN_STATIC_DELAY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSSFC_ATTR_DVBT2_SFN_DYNAMIC_DELAY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSSFC_ATTR_DVBT2_SFN_TOTAL_DELAY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSSFC_ATTR_DVBT2_SFN_MAX_DEVIATION_TIME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSSFC_ATTR_DVBT2_SFN_MUTE_FIRST_P1_OF_SUPER_FRAME                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 583
#define RSSFC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_DATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSSFC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_UTC_TIME                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 658
#define RSSFC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_SECONDS_SINCE_2000              RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSSFC_ATTR_DVBT2_SFN_UPDATE_TIMESTAMP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 660
#define RSSFC_ATTR_DVBT2_SFN_TIMESTAMP_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 661
#define RSSFC_ATTR_DVBT2_SFN_TIMESTAMP_MODE_OFFSET                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSSFC_ATTR_DVBT2_SETTINGS_TEST_TS_PACKET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 366
#define RSSFC_ATTR_DVBT2_SETTINGS_PAYLOAD_TEST_TS_PACKET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 367
#define RSSFC_ATTR_DVBT2_SETTINGS_PRBS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 368
#define RSSFC_ATTR_DVBC2_INPUT_SIGNAL_NUMBER_OF_PLP                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 584
#define RSSFC_ATTR_DVBC2_INPUT_SIGNAL_INPUT_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 585
#define RSSFC_ATTR_DVBC2_INPUT_SIGNAL_SOURCE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 586
#define RSSFC_ATTR_DVBC2_INPUT_SIGNAL_INPUT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 587
#define RSSFC_ATTR_READ_DVBC2_INPUT_SIGNAL_MAX_DR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 588
#define RSSFC_ATTR_READ_DVBC2_INPUT_SIGNAL_MEAS_DR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 589
#define RSSFC_ATTR_READ_DVBC2_INPUT_SIGNAL_USEFUL_DR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 590
#define RSSFC_ATTR_DVBC2_INPUT_SIGNAL_TEST_SIGNAL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 591
#define RSSFC_ATTR_DVBC2_MODE_STREAM_ADAPT_PLP_ID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 592
#define RSSFC_ATTR_DVBC2_MODE_STREAM_ADAPT_PLP_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 593
#define RSSFC_ATTR_DVBC2_MODE_STREAM_ADAPT_BB_MODE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSSFC_ATTR_DVBC2_MODE_STREAM_ADAPT_ISSY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 595
#define RSSFC_ATTR_DVBC2_MODE_STREAM_ADAPT_NULL_PACKET_DEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 596
#define RSSFC_ATTR_DVBC2_BICM_FEC_FRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSSFC_ATTR_DVBC2_BICM_CODE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define RSSFC_ATTR_DVBC2_BICM_CONSTELL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSSFC_ATTR_DVBC2_BICM_XFEC_FRAME_LENGTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define RSSFC_ATTR_DVBC2_BICM_MAP_TO_DSLICE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define RSSFC_ATTR_DVBC2_DATA_SLICE_MIN_MAX_REL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 602
#define RSSFC_ATTR_DVBC2_DATA_SLICE_MIN_MAX_ABS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define RSSFC_ATTR_DVBC2_DATA_SLICE_NUMBER_OF_DATA_SLICES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define RSSFC_ATTR_DVBC2_DATA_SLICE_DSLICE_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 605
#define RSSFC_ATTR_DVBC2_DATA_SLICE_DSLICE_TI_DEPTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define RSSFC_ATTR_DVBC2_DATA_SLICE_DSLICE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 607
#define RSSFC_ATTR_DVBC2_DATA_SLICE_FEC_HEADER_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 608
#define RSSFC_ATTR_DVBC2_DATA_SLICE_NUM_XFEC_FRAMES                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSSFC_ATTR_DVBC2_DATA_SLICE_DSLICE_NUM_PLP                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 610
#define RSSFC_ATTR_DVBC2_DATA_SLICE_OFFSET_LEFT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSSFC_ATTR_DVBC2_DATA_SLICE_TUNE_POS_REL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 612
#define RSSFC_ATTR_DVBC2_DATA_SLICE_OFFSET_RIGHT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSSFC_ATTR_DVBC2_DATA_SLICE_START_REL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 614
#define RSSFC_ATTR_DVBC2_DATA_SLICE_STOP_REL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define RSSFC_ATTR_DVBC2_DATA_SLICE_WIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define RSSFC_ATTR_DVBC2_DATA_SLICE_START_ABS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSSFC_ATTR_DVBC2_DATA_SLICE_TUNE_POS_ABS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define RSSFC_ATTR_DVBC2_DATA_SLICE_STOP_ABS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define RSSFC_ATTR_DVBC2_DATA_SLICE_TUNE_FREQ                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSSFC_ATTR_DVBC2_DATA_SLICE_START_FREQ                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSSFC_ATTR_DVBC2_DATA_SLICE_STOP_FREQ                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSSFC_ATTR_DVBC2_NOTCH_NUMBER_OF_NOTCHES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSSFC_ATTR_DVBC2_NOTCH_START_REL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 621
#define RSSFC_ATTR_DVBC2_NOTCH_STOP_REL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 622
#define RSSFC_ATTR_DVBC2_NOTCH_START_ABS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define RSSFC_ATTR_DVBC2_NOTCH_STOP_ABS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSSFC_ATTR_DVBC2_NOTCH_WIDTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define RSSFC_ATTR_DVBC2_NOTCH_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSSFC_ATTR_DVBC2_NOTCH_START_FREQ                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSSFC_ATTR_DVBC2_NOTCH_STOP_FREQ                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSSFC_ATTR_DVBC2_FRAMING_CHANNEL_BANDWIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 626
#define RSSFC_ATTR_DVBC2_FRAMING_USED_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 628
#define RSSFC_ATTR_DVBC2_FRAMING_C2_BANDWIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSSFC_ATTR_DVBC2_FRAMING_GUARD_INTERVAL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 629
#define RSSFC_ATTR_DVBC2_FRAMING_BASEBAND_FILTER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSSFC_ATTR_DVBC2_FRAMING_DX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 630
#define RSSFC_ATTR_DVBC2_FRAMING_START_FREQUENCY                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 631
#define RSSFC_ATTR_DVBC2_FRAMING_CARRIER_SPACING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSSFC_ATTR_DVBC2_FRAMING_CALC_CENTER_FREQUENCY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSSFC_ATTR_DVBC2_FRAMING_ADJUST_RF_FREQUENCY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSSFC_ATTR_DVBC2_FRAMING_NUMBER_OF_DATA_SYMBOLS_PER_C2_FRAME        RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSSFC_ATTR_DVBC2_FRAMING_NUMBER_OF_PREAMBLE_SYMBOLS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSSFC_ATTR_DVBC2_C2_SYSTEM_NETWORK_ID                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSSFC_ATTR_DVBC2_C2_SYSTEM_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSSFC_ATTR_DVBC2_C2_SYSTEM_L1_TIME_INTERLEAVER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSSFC_ATTR_DVBC2_C2_SYSTEM_RESERVED_TONES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSSFC_ATTR_DVBC2_SETTINGS_TEST_TS_PACKET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSSFC_ATTR_DVBC2_SETTINGS_PAYLOAD_TEST_TS_PACKET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSSFC_ATTR_DVBC2_SETTINGS_PRBS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSSFC_ATTR_ATV_VIDEO_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 369
#define RSSFC_ATTR_ATV_VISION_PICTURE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 370
#define RSSFC_ATTR_ATV_LOAD_VIDEO_LIB                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 375
#define RSSFC_ATTR_ATV_AUDIO_INPUT_SIGNAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 377
#define RSSFC_ATTR_ATV_FREQ_SOUND_MONO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSSFC_ATTR_ATV_LEVEL_SOUND_MONO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 379
#define RSSFC_ATTR_ATV_FREQ_SOUND_LEFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSSFC_ATTR_ATV_FREQ_SOUND_RIGHT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSSFC_ATTR_ATV_LEVEL_SOUND_LEFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSSFC_ATTR_ATV_LEVEL_SOUND_RIGHT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define RSSFC_ATTR_ATV_FREQ_SOUND_CH1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 384
#define RSSFC_ATTR_ATV_FREQ_SOUND_CH2                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 385
#define RSSFC_ATTR_ATV_LEVEL_SOUND_CH1                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSSFC_ATTR_ATV_LEVEL_SOUND_CH2                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSSFC_ATTR_ATV_AUDIO_AF_1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSSFC_ATTR_ATV_AUDIO_AF_2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSSFC_ATTR_ANALOG_TV_AUDIO_LOAD_AUDIO_PLAYER_FILE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSSFC_ATTR_ANALOG_TV_NICAM_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSSFC_ATTR_ANALOG_TV_NICAM_SOUND_MODE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSSFC_ATTR_ANALOG_TV_NICAM_AF_1                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 395
#define RSSFC_ATTR_ANALOG_TV_NICAM_FREQUENCY_SOUND_LEFT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSSFC_ATTR_ANALOG_TV_NICAM_FREQUENCY_SOUND_CHANNEL_1                RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSSFC_ATTR_ANALOG_TV_NICAM_FREQUENCY_SOUND_CHANNEL_2                RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSSFC_ATTR_ANALOG_TV_NICAM_FREQUENCY_SOUND_MONO                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSSFC_ATTR_ANALOG_TV_NICAM_LEVEL_SOUND_LEFT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 400
#define RSSFC_ATTR_ANALOG_TV_NICAM_LEVEL_SOUND_CHANNEL_1                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSSFC_ATTR_ANALOG_TV_NICAM_LEVEL_SOUND_CHANNEL_2                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 402
#define RSSFC_ATTR_ANALOG_TV_NICAM_LEVEL_SOUND_MONO                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSSFC_ATTR_ANALOG_TV_NICAM_AF_2                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSSFC_ATTR_ANALOG_TV_NICAM_FREQUENCY_SOUND_RIGHT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSSFC_ATTR_ANALOG_TV_NICAM_LEVEL_SOUND_RIGHT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 406
#define RSSFC_ATTR_ATV_SOUND_MODUL_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 407
#define RSSFC_ATTR_ATV_SOUND_MODUL_FREQ_DEV_SUBCAR1                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 408
#define RSSFC_ATTR_ATV_SOUND_MODUL_FREQ_DEV_SUBCAR2                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 409
#define RSSFC_ATTR_ATV_SOUND_MODUL_FREQ_DEV_PILOT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSSFC_ATTR_ATV_SOUND_MODUL_FREQ_DEV_MONO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 411
#define RSSFC_ATTR_ATV_SPECIAL_SETTINGS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSSFC_ATTR_ATV_SPECIAL_PREEMPHASIS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSSFC_ATTR_ATV_SPECIAL_PILOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 414
#define RSSFC_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_PILOT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 415
#define RSSFC_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_MONO                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 416
#define RSSFC_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_SUBCAR_1                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 417
#define RSSFC_ATTR_ATV_SPECIAL_NOM_FREQ_DEV_SUBCAR_2                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 418
#define RSSFC_ATTR_ATV_SPECIAL_SUBCARRIER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 419
#define RSSFC_ATTR_ATV_SPECIAL_SUBCARRIER_1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 420
#define RSSFC_ATTR_ATV_SPECIAL_SUBCARRIER_2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 421
#define RSSFC_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSSFC_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER_1                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSSFC_ATTR_ATV_SPECIAL_FREQ_SUBCARRIER_2                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSSFC_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 425
#define RSSFC_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER_1                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 426
#define RSSFC_ATTR_ATV_SPECIAL_LEVEL_SUBCARRIER_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define RSSFC_ATTR_ATV_SPECIAL_VSB_FILTER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 428
#define RSSFC_ATTR_ATV_SPECIAL_VSB_CHARACTERISTIC                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 429
#define RSSFC_ATTR_ATV_SPECIAL_GD_PRECORRECTION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 430
#define RSSFC_ATTR_ATV_SPECIAL_RESIDUAL_CARRIER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 431
#define RSSFC_ATTR_ATV_SPECIAL_CARRIER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 432
#define RSSFC_ATTR_ATV_SPECIAL_VIDEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 433
#define RSSFC_ATTR_ATV_SPECIAL_AM_MODULATION_DEPTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 434
#define RSSFC_ATTR_ANALOG_TV_SPECIAL_NICAM_PREEMPHASIS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 435
#define RSSFC_ATTR_ANALOG_TV_SPECIAL_NICAM_GAIN_ADJUST_1                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 436
#define RSSFC_ATTR_ANALOG_TV_SPECIAL_NICAM_GAIN_ADJUST_2                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 437
#define RSSFC_ATTR_ANALOG_TV_SPECIAL_NICAM_ROLL_OFF                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 438
#define RSSFC_ATTR_AUDIO_BC_SOURCE_LEFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSSFC_ATTR_AUDIO_BC_SOURCE_RIGHT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSSFC_ATTR_AUDIO_BC_AF_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSSFC_ATTR_AUDIO_BC_SOURCE_FREQUENCY_LEFT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSSFC_ATTR_AUDIO_BC_SOURCE_FREQUENCY_RIGHT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSSFC_ATTR_AUDIO_BC_SOURCE_LEVEL_LEFT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSSFC_ATTR_AUDIO_BC_SOURCE_LEVEL_RIGHT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 453
#define RSSFC_ATTR_AUDIO_BC_RDS_GROUP_SEQUENCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSSFC_ATTR_AUDIO_BC_RDS_PI                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSSFC_ATTR_AUDIO_BC_RDS_PS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSSFC_ATTR_AUDIO_BC_RDS_TP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSSFC_ATTR_AUDIO_BC_RDS_TA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSSFC_ATTR_AUDIO_BC_RDS_PTY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSSFC_ATTR_AUDIO_BC_RDS_PTYN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 462
#define RSSFC_ATTR_AUDIO_BC_RDS_RT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 463
#define RSSFC_ATTR_AUDIO_BC_RDS_RT_READY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 464
#define RSSFC_ATTR_AUDIO_BC_RDS_MS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_DYNAMIC_PTY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_COMPRESSED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_ART_HEAD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 468
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_STEREO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_CT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 470
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_CT_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSSFC_ATTR_AUDIO_BC_RDS_DI_AF_METHOD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSSFC_ATTR_AUDIO_BC_AF_A_NUMBER_OF_FREQ                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSSFC_ATTR_AUDIO_BC_AF_A_FREQUENCY                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 474
#define RSSFC_ATTR_AUDIO_BC_AF_B_NUMBER_OF_LISTS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSSFC_ATTR_AUDIO_BC_AF_B_NUMBER_OF_FREQ                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSSFC_ATTR_AUDIO_BC_AF_B_TUNING_FREQ                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSSFC_ATTR_AUDIO_BC_AF_B_AF_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSSFC_ATTR_AUDIO_BC_AF_B_AF_ORDER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define RSSFC_ATTR_AUDIO_BC_EON_PI                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSSFC_ATTR_AUDIO_BC_EON_PS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSSFC_ATTR_AUDIO_BC_EON_TP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define RSSFC_ATTR_AUDIO_BC_EON_TA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 483
#define RSSFC_ATTR_AUDIO_BC_EON_LA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 484
#define RSSFC_ATTR_AUDIO_BC_EON_EG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 485
#define RSSFC_ATTR_AUDIO_BC_EON_ILS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 486
#define RSSFC_ATTR_AUDIO_BC_EON_LSN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 487
#define RSSFC_ATTR_AUDIO_BC_EON_PTY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define RSSFC_ATTR_AUDIO_BC_EON_PIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define RSSFC_ATTR_AUDIO_BC_EON_AF_METHOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSSFC_ATTR_AUDIO_BC_EON_AF_A_NUMBER_OF_FREQ                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSSFC_ATTR_AUDIO_BC_EON_AF_A_FREQUENCY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSSFC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_NUMBER_OF_FREQ               RS_SPECIFIC_PUBLIC_ATTR_BASE + 493
#define RSSFC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_TUNING_FREQ                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define RSSFC_ATTR_AUDIO_BC_EON_AF_MAPPED_FREQ_AF_FREQUENCY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define RSSFC_ATTR_AUDIO_BC_TMC_TMC                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSSFC_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_00                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSSFC_ATTR_AUDIO_BC_TMC_GROUP_3A_VAR_01                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 498
#define RSSFC_ATTR_AUDIO_BC_TMC_NUMBER_OF_8A_GROUPS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 499
#define RSSFC_ATTR_AUDIO_BC_TMC_8A_BLOCK                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSSFC_ATTR_AUDIO_BC_TMC_APPLY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 501
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 502
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT_APPLY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_A                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 504
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_B                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 505
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_A_READY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 506
#define RSSFC_ATTR_AUDIO_BC_OPEN_FORMAT_GROUP_B_READY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define RSSFC_ATTR_AUDIO_BC_MODULATION_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define RSSFC_ATTR_AUDIO_BC_MODULATION_PREEMPHASIS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define RSSFC_ATTR_AUDIO_BC_MODULATION_RDS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 510
#define RSSFC_ATTR_AUDIO_BC_MODULATION_NOM_FREQ_DEV_AUDIO                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define RSSFC_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_AUDIO                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define RSSFC_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_RDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 513
#define RSSFC_ATTR_AUDIO_BC_MODULATION_FREQ_DEV_PILOT_19KHZ                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define RSSFC_ATTR_AUDIO_BC_FM_SPECIAL_SETTINGS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSSFC_ATTR_AUDIO_BC_SPECIAL_PILOT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 518
#define RSSFC_ATTR_AUDIO_BC_SPECIAL_PHASE_OFFSET_PILOT_19KHZ                RS_SPECIFIC_PUBLIC_ATTR_BASE + 519
#define RSSFC_ATTR_AUDIO_BC_SPECIAL_PHASE_OFFSET_RDS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 520
#define RSSFC_ATTR_AUDIO_BC_AM_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define RSSFC_ATTR_AUDIO_BC_AM_INTERNAL_FREQUENCY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define RSSFC_ATTR_AUDIO_BC_AM_INTERNAL_LEVEL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 523
#define RSSFC_ATTR_AUDIO_BC_AM_NOM_MOD_DEPTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define RSSFC_ATTR_AUDIO_BC_AM_MOD_DEPTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define RSSFC_ATTR_NOISE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSSFC_ATTR_NOISE_CN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 443
#define RSSFC_ATTR_NOISE_BANDWIDTH_COUPLING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSSFC_ATTR_NOISE_RECEIVER_BANDWIDTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSSFC_ATTR_GEN_NOISE_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSSFC_ATTR_AWGN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSSFC_ATTR_TSGEN_COMMAND                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define RSSFC_ATTR_TSGEN_COMMAND_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSSFC_ATTR_TSGEN_SEEK_POSITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 543
#define RSSFC_ATTR_TSGEN_PLAYER_PLAYFILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 544
#define RSSFC_ATTR_TSGEN_FILE_DATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSSFC_ATTR_TSGEN_ORIGINAL_TS_DATA_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSSFC_ATTR_TSGEN_PLAYER_BYTERATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define RSSFC_ATTR_TSGEN_TS_DATA_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define RSSFC_ATTR_TSGEN_PLAY_WINDOW_START                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSSFC_ATTR_TSGEN_PLAY_WINDOW_STOP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSSFC_ATTR_TSGEN_PACKET_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSSFC_ATTR_TSGEN_ORIGINAL_LOOP_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define RSSFC_ATTR_TSGEN_PLAYER_NULLPACKET_STUFFING                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSSFC_ATTR_TSGEN_SEAMLESS_LOOP_CONT_COUNT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define RSSFC_ATTR_TSGEN_SEAMLESS_LOOP_PCR_DTS_PTS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSSFC_ATTR_TSGEN_SEAMLESS_LOOP_TDT_TOT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSSFC_ATTR_CAL_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define RSSFC_ATTR_CAL_ALL_RESULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSSFC_ATTR_CAL_LOCAL_DATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSSFC_ATTR_CAL_LOCAL_RESULT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSSFC_ATTR_CAL_LOCAL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSSFC_ATTR_CAL_IQM_FULL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSSFC_ATTR_CAL_IQM_FULL_RESULT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSSFC_ATTR_CAL_IQM_FULL_DATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSSFC_ATTR_CAL_LEV_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSSFC_ATTR_ROSC_ADJ_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 566
#define RSSFC_ATTR_ROSC_ADJ_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSSFC_ATTR_ROSC_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSSFC_ATTR_SYSTEM_DISPLAY_UPDATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 570
#define RSSFC_ATTR_SYSTEM_KLOCK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSSFC_ATTR_SYST_PRESET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSSFC_ATTR_RCL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSSFC_ATTR_SAV                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define RSSFC_ATTR_SERVICE_STEST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSSFC_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 576

// rssfc_rngCalibrationResult
#define RSSFC_VAL_FAIL                                                      0
#define RSSFC_VAL_PASS                                                      1

// rssfc_rngIqcInp
#define RSSFC_IQC_ASI1                                                      0
#define RSSFC_IQC_SMP1                                                      1

// rssfc_rngIqcDtmbGic
#define RSSFC_VAL_IQC_DTMB_GIC_VAR                                          0
#define RSSFC_VAL_IQC_DTMB_GIC_CONST                                        1

// rssfc_rngIqcPrbsMode
#define RSSFC_IQC_PRBS_P231                                                 0
#define RSSFC_IQC_PRBS_P151                                                 1

// rssfc_rngIqcSigSour
#define RSSFC_IQC_SIG_SOUR_EXT                                              0
#define RSSFC_IQC_SIG_SOUR_TSP                                              1
#define RSSFC_IQC_SIG_SOUR_TEST                                             2

// rssfc_rngIqcTestSig
#define RSSFC_IQC_TEST_TTSP                                                 0
#define RSSFC_IQC_TEST_PAFC                                                 1
#define RSSFC_IQC_TEST_PBEC                                                 2
#define RSSFC_IQC_TEST_PBEM                                                 3

// rssfc_rngIqcTimeInter
#define RSSFC_IQC_TINT_OFF                                                  0
#define RSSFC_IQC_TINT_I240                                                 2
#define RSSFC_IQC_TINT_I720                                                 3

// rssfc_rngIqcDvbtChanBw
#define RSSFC_IQC_DVBT_CHBW6                                                0
#define RSSFC_IQC_DVBT_CHBW7                                                1
#define RSSFC_IQC_DVBT_CHBW8                                                2
#define RSSFC_IQC_DVBT_CHBW5                                                3

// rssfc_rngIqcDvbtCons
#define RSSFC_IQC_CONST_QPSK                                                0
#define RSSFC_IQC_CONST_16QAM                                               1
#define RSSFC_IQC_CONST_64QAM                                               2

// rssfc_rngIqcDvbtSymb
#define RSSFC_IQC_DVBT_SYMB_NAT                                             0
#define RSSFC_IQC_DVBT_SYMB_IND                                             1

// rssfc_rngIqcDvbtFftMode
#define RSSFC_IQC_DVBT_FFT_M2K                                              0
#define RSSFC_IQC_DVBT_FFT_M4K                                              1
#define RSSFC_IQC_DVBT_FFT_M8K                                              2

// rssfc_rngIqcDvbtGuarInt
#define RSSFC_IQC_DVBT_GUAR_14                                              0
#define RSSFC_IQC_DVBT_GUAR_18                                              1
#define RSSFC_IQC_DVBT_GUAR_16                                              2
#define RSSFC_IQC_DVBT_GUAR_32                                              3

// rssfc_rngIqcDvbtHier
#define RSSFC_IQC_DVBT_HIER_NONE                                            0
#define RSSFC_IQC_DVBT_HIER_A1                                              1
#define RSSFC_IQC_DVBT_HIER_A2                                              2
#define RSSFC_IQC_DVBT_HIER_A4                                              3

// rssfc_rngDigMod
#define RSSFC_VAL_DIG_MOD_WBNC                                              0
#define RSSFC_VAL_DIG_MOD_WBEC                                              1
#define RSSFC_VAL_DIG_MOD_DIVN                                              2
#define RSSFC_VAL_DIG_MOD_NRWN                                              3
#define RSSFC_VAL_DIG_MOD_NWEC                                              4
#define RSSFC_VAL_DIG_MOD_AUTO                                              5

// rssfc_rngDmSigSource
#define RSSFC_VAL_DM_SOURCE_ATV                                             0
#define RSSFC_VAL_DM_SOURCE_DTV                                             1
#define RSSFC_VAL_DM_SOURCE_AUDIO                                           2
#define RSSFC_VAL_DM_SOURCE_DIG                                             3

// rssfc_rngDmTransmStd
#define RSSFC_VAL_DM_STANDARD_DVBT                                          0
#define RSSFC_VAL_DM_STANDARD_DVBC                                          1
#define RSSFC_VAL_DM_STANDARD_DVBS                                          2
#define RSSFC_VAL_DM_STANDARD_8VSB                                          3
#define RSSFC_VAL_DM_STANDARD_J83B                                          4
#define RSSFC_VAL_DM_STANDARD_ISDBT                                         5
#define RSSFC_VAL_DM_STANDARD_DMBT                                          6
#define RSSFC_VAL_DM_STANDARD_DVBS2                                         7
#define RSSFC_VAL_DM_STANDARD_DIR                                           8
#define RSSFC_VAL_DM_STANDARD_TDMB                                          9
#define RSSFC_VAL_DM_STANDARD_MEDIAFLO                                      10
#define RSSFC_VAL_DM_STANDARD_DTMB                                          11
#define RSSFC_VAL_DM_STANDARD_CMMB                                          12
#define RSSFC_VAL_DM_STANDARD_ATSM                                          13
#define RSSFC_VAL_DM_STANDARD_T2DVB                                         14
#define RSSFC_VAL_DM_STANDARD_C2DVB                                         15

// rssfc_rngDmSpectPolar
#define RSSFC_VAL_DM_SPEC_POLAR_NORM                                        0
#define RSSFC_VAL_DM_SPEC_POLAR_INV                                         1

// rssfc_rngNoiseState
#define RSSFC_VAL_NOISE_OFF                                                 0
#define RSSFC_VAL_NOISE_ADD                                                 1
#define RSSFC_VAL_NOISE_ONLY                                                2

// rssfc_rngPowLevUnit
#define RSSFC_VAL_POW_LEV_DBM                                               0
#define RSSFC_VAL_POW_LEV_DBUV                                              1
#define RSSFC_VAL_POW_LEV_MV                                                2
#define RSSFC_VAL_POW_LEV_DBMV                                              3

// rssfc_rngRoscSource
#define RSSFC_VAL_ROSC_SOURCE_INT                                           0
#define RSSFC_VAL_ROSC_SOURCE_EXT                                           1

// rssfc_rngTsgenCommand
#define RSSFC_VAL_TSGEN_STOP                                                0
#define RSSFC_VAL_TSGEN_PAUSE                                               1
#define RSSFC_VAL_TSGEN_PLAY                                                2

// rssfc_rngTdmbSource
#define RSSFC_VAL_TDMB_EXT                                                  0
#define RSSFC_VAL_TDMB_GEN                                                  1
#define RSSFC_VAL_TDMB_TEST                                                 2

// rssfc_rngTdmbTranMode
#define RSSFC_VAL_TDMB_TRAN_MODE_MID                                        0
#define RSSFC_VAL_TDMB_TRAN_MODE_MANUAL                                     1

// rssfc_rngTdmbPrbsSeq
#define RSSFC_VAL_TDMB_PRBS_P23_1                                           0
#define RSSFC_VAL_TDMB_PRBS_P15_1                                           1
#define RSSFC_VAL_TDMB_PRBS_P20_1                                           2
#define RSSFC_VAL_TDMB_PRBS_ZERO                                            3

// rssfc_rngTdmbProtProfile
#define RSSFC_VAL_TDMB_PROFILE_UEP                                          0
#define RSSFC_VAL_TDMB_PROFILE_EEP                                          1

// rssfc_rngTdmbProtLevel
#define RSSFC_VAL_TDMB_LEVEL_UP1                                            0
#define RSSFC_VAL_TDMB_LEVEL_UP2                                            1
#define RSSFC_VAL_TDMB_LEVEL_UP3                                            2
#define RSSFC_VAL_TDMB_LEVEL_UP4                                            3
#define RSSFC_VAL_TDMB_LEVEL_UP5                                            4
#define RSSFC_VAL_TDMB_LEVEL_EP1A                                           5
#define RSSFC_VAL_TDMB_LEVEL_EP2A                                           6
#define RSSFC_VAL_TDMB_LEVEL_EP3A                                           7
#define RSSFC_VAL_TDMB_LEVEL_EP4A                                           8
#define RSSFC_VAL_TDMB_LEVEL_EP1B                                           9
#define RSSFC_VAL_TDMB_LEVEL_EP2B                                           10
#define RSSFC_VAL_TDMB_LEVEL_EP3B                                           11
#define RSSFC_VAL_TDMB_LEVEL_EP4B                                           12

// rssfc_rngTdmbETI
#define RSSFC_VAL_TDMB_ETINPUT_INV                                          0
#define RSSFC_VAL_TDMB_ETINPUT_ENI                                          1
#define RSSFC_VAL_TDMB_ETINPUT_E559                                         2
#define RSSFC_VAL_TDMB_ETINPUT_E537                                         3

// rssfc_rngDmAtvTransmStd
#define RSSFC_VAL_DM_ATV_STANDARD_BG                                        0
#define RSSFC_VAL_DM_ATV_STANDARD_DK                                        1
#define RSSFC_VAL_DM_ATV_STANDARD_I                                         2
#define RSSFC_VAL_DM_ATV_STANDARD_MN                                        3
#define RSSFC_VAL_DM_ATV_STANDARD_L                                         4

// rssfc_rngFreqVsbFreq
#define RSSFC_VAL_FREQ_VSB_FREQ_PILOT                                       0
#define RSSFC_VAL_FREQ_VSB_FREQ_CENTER                                      1

// rssfc_rngSystemKLock
#define RSSFC_VAL_SYST_KLOCK_OFF                                            0
#define RSSFC_VAL_SYST_KLOCK_ON                                             1

// rssfc_rngTsgenCommandState
#define RSSFC_VAL_TSGEN_STAT_STOP                                           0
#define RSSFC_VAL_TSGEN_STAT_PAUSE                                          1
#define RSSFC_VAL_TSGEN_STAT_RUN                                            2

// rssfc_rngIqcDtmbPackLength
#define RSSFC_VAL_IQC_DTMB_PACK_LEN_INV                                     0
#define RSSFC_VAL_IQC_DTMB_PACK_LEN_P188                                    1

// rssfc_rngIqcDtmbChanBw
#define RSSFC_IQC_DTMB_CHBW6                                                1
#define RSSFC_IQC_DTMB_CHBW7                                                2
#define RSSFC_IQC_DTMB_CHBW8                                                3

// rssfc_rngIqcDtmbCodeRate
#define RSSFC_IQC_DTMB_CRATE_04                                             0
#define RSSFC_IQC_DTMB_CRATE_06                                             1
#define RSSFC_IQC_DTMB_CRATE_08                                             2

// rssfc_rngDtmbPrbsSeq
#define RSSFC_VAL_DTMB_PRBS_P23_1                                           0
#define RSSFC_VAL_DTMB_PRBS_P15_1                                           1

// rssfc_rngIqcDtmbCons
#define RSSFC_IQC_DTMB_CONST_4QAM                                           0
#define RSSFC_IQC_DTMB_CONST_4QAM_NR                                        1
#define RSSFC_IQC_DTMB_CONST_16QAM                                          2
#define RSSFC_IQC_DTMB_CONST_32QAM                                          3
#define RSSFC_IQC_DTMB_CONST_64QAM                                          4

// rssfc_rngIqcDtmbGuar
#define RSSFC_IQC_GUAR_G420                                                 0
#define RSSFC_IQC_GUAR_G595                                                 1
#define RSSFC_IQC_GUAR_G945                                                 2

// rssfc_rngIqcDtmbNetw
#define RSSFC_IQC_NETW_SFN                                                  0
#define RSSFC_IQC_NETW_MFN                                                  1

// rssfc_rngDmAudioStd
#define RSSFC_VAL_DM_AUDIO_STD_AM                                           0
#define RSSFC_VAL_DM_AUDIO_STD_FM                                           1

// rssfc_rngRfoutAmode
#define RSSFC_RFOUT_AMODE_AUTO                                              0
#define RSSFC_RFOUT_AMODE_FIX                                               1

// rssfc_rngIqcTestSigDTMB
#define RSSFC_DTMB_TEST_TTSP                                                0
#define RSSFC_DTMB_TEST_PBEM                                                1

// rssfc_rngIqcIsdbtSystem
#define RSSFC_VAL_IQC_ISDBT_SYSTEM_T                                        0
#define RSSFC_VAL_IQC_ISDBT_SYSTEM_TSB1                                     1
#define RSSFC_VAL_IQC_ISDBT_SYSTEM_TSB3                                     2

// rssfc_rngIqcIsdbtPortion
#define RSSFC_IQC_VAL_ISDBT_PORTION_PDD                                     0
#define RSSFC_IQC_VAL_ISDBT_PORTION_PDC                                     1
#define RSSFC_IQC_VAL_ISDBT_PORTION_PCC                                     2
#define RSSFC_IQC_VAL_ISDBT_PORTION_DDD                                     3
#define RSSFC_IQC_VAL_ISDBT_PORTION_DDC                                     4
#define RSSFC_IQC_VAL_ISDBT_PORTION_DCC                                     5
#define RSSFC_IQC_VAL_ISDBT_PORTION_CCC                                     6

// rssfc_rngIqcIsdbtConstel
#define RSSFC_IQC_VAL_ISDBT_CONSTEL_DQPSK                                   0
#define RSSFC_IQC_VAL_ISDBT_CONSTEL_QPSK                                    1
#define RSSFC_IQC_VAL_ISDBT_CONSTEL_16QAM                                   2
#define RSSFC_IQC_VAL_ISDBT_CONSTEL_64QAM                                   3

// rssfc_rngIqcCodeRate
#define RSSFC_IQC_CRATE_12                                                  0
#define RSSFC_IQC_CRATE_23                                                  1
#define RSSFC_IQC_CRATE_34                                                  2
#define RSSFC_IQC_CRATE_56                                                  3
#define RSSFC_IQC_CRATE_78                                                  4
#define RSSFC_IQC_CRATE_89                                                  5

// rssfc_rngIqcIsdbtInterleaving
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_0                                    0
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_1                                    1
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_2                                    2
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_4                                    3
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_8                                    4
#define RSSFC_VAL_IQC_ISDBT_TIME_INTER_16                                   5

// rssfc_rngIqcIsdbtMode
#define RSSFC_VAL_IQC_ISDBT_MODE_2K                                         0
#define RSSFC_VAL_IQC_ISDBT_MODE_4K                                         1
#define RSSFC_VAL_IQC_ISDBT_MODE_8K                                         2

// rssfc_rngIqcIsdbtGuardInt
#define RSSFC_VAL_IQC_ISDBT_GUARD_1_4                                       0
#define RSSFC_VAL_IQC_ISDBT_GUARD_1_8                                       1
#define RSSFC_VAL_IQC_ISDBT_GUARD_1_16                                      2
#define RSSFC_VAL_IQC_ISDBT_GUARD_1_32                                      3

// rssfc_rngIqcTestPacketMode
#define RSSFC_IQC_TS_MODE_HEAD                                              0
#define RSSFC_IQC_TS_MODE_SYNC                                              1

// rssfc_rngIqcIsdbtAcData
#define RSSFC_VAL_IQC_ISDBT_AC_DATA_PRBS                                    0
#define RSSFC_VAL_IQC_ISDBT_AC_DATA_ALL1                                    1

// rssfc_rngIqcAtvVideoInput
#define RSSFC_VAL_IQC_ATV_VIDEO_SOURCE_VGEN                                 0

// rssfc_rngIqcAtvVisionPict
#define RSSFC_VAL_IQC_VISION_PICT_C75P                                      0
#define RSSFC_VAL_IQC_VISION_PICT_C75N                                      1
#define RSSFC_VAL_IQC_VISION_PICT_C75S                                      2
#define RSSFC_VAL_IQC_VISION_PICT_FUBP                                      3
#define RSSFC_VAL_IQC_VISION_PICT_CPAM                                      4
#define RSSFC_VAL_IQC_VISION_PICT_CPAN                                      5
#define RSSFC_VAL_IQC_VISION_PICT_LIBR                                      6

// rssfc_rngIqcAtvAudioSource
#define RSSFC_VAL_IQC_ATV_AUDIO_SOURCE_AGEN                                 0
#define RSSFC_VAL_IQC_ATV_AUDIO_SOURCE_APL                                  1

// rssfc_rngIqcAtvSoundMode
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_OFF                                    0
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_FMM                                    1
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_FMST                                   2
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_FMD                                    3
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_BTSC                                   4
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_NIC                                    5
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_AMM                                    6
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_MNIC                                   7
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_FMSK                                   8
#define RSSFC_VAL_IQC_ATV_SOUND_MODE_FMDK                                   9

// rssfc_rngIqcAtvPreemphasis
#define RSSFC_VAL_IQC_ATV_PREEMPHASIS_OFF                                   0
#define RSSFC_VAL_IQC_ATV_PREEMPHASIS_D50                                   1
#define RSSFC_VAL_IQC_ATV_PREEMPHASIS_D75                                   2

// rssfc_rngIqcAtvSpecialVsbChar
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DKFM                             0
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DK                               1
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_DKN                              2
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_I                                3
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_I1                               4
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_M                                5
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_N                                6
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_BG                               7
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_L                                8
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_LNIC                             9
#define RSSFC_VAL_IQC_ATV_SPECIAL_VSB_CHAR_BGA                              10

// rssfc_rngIqcAtvNicamSpecRoll
#define RSSFC_VAL_IQC_ATV_NICAM_ROLLOFF_R40                                 0
#define RSSFC_VAL_IQC_ATV_NICAM_ROLLOFF_R100                                1

// rssfc_rngIqcAtvNicamSource
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_NENCODER                               0
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_NEXTERNAL                              1
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_NGENER                                 2
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_PRBS                                   3
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_APLAYER                                4

// rssfc_rngIqcAtvNicamMode
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_MONO                                   0
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_STEREO                                 1
#define RSSFC_VAL_IQC_ATV_NICAM_SOUR_DUAL                                   2

// rssfc_rngIqcIsdbtTestSig
#define RSSFC_IQC_ISDBT_TEST_TTSP                                           0
#define RSSFC_IQC_ISDBT_TEST_PBEC                                           1
#define RSSFC_IQC_ISDBT_TEST_PAFC                                           2

// rssfc_rngIqcDvbcCons
#define RSSFC_IQC_DVBC_CONS_16QAM                                           0
#define RSSFC_IQC_DVBC_CONS_32QAM                                           1
#define RSSFC_IQC_DVBC_CONS_64QAM                                           2
#define RSSFC_IQC_DVBC_CONS_128QAM                                          3
#define RSSFC_IQC_DVBC_CONS_256QAM                                          4

// rssfc_rngIqcDvbcRollOff
#define RSSFC_VAL_DVBC_ROLL_OFF_0_10                                        0
#define RSSFC_VAL_DVBC_ROLL_OFF_0_13                                        1
#define RSSFC_VAL_DVBC_ROLL_OFF_0_15                                        2
#define RSSFC_VAL_DVBC_ROLL_OFF_0_18                                        3
#define RSSFC_VAL_DVBC_ROLL_OFF_0_20                                        4

// rssfc_rngIqcDvbsCons
#define RSSFC_IQC_DVBS_CONS_QPSK                                            0
#define RSSFC_IQC_DVBS_CONS_8PSK                                            1
#define RSSFC_IQC_DVBS_CONS_16QAM                                           2

// rssfc_rngIqcDvbsRolloff
#define RSSFC_VAL_DVBS_ROLL_OFF_0_25                                        0
#define RSSFC_VAL_DVBS_ROLL_OFF_0_35                                        2
#define RSSFC_VAL_DVBS_ROLL_OFF_0_20                                        3

// rssfc_rngIqcPackedLength
#define RSSFC_VAL_IQC_PACK_LEN_INV                                          0
#define RSSFC_VAL_IQC_PACK_LEN_P188                                         1
#define RSSFC_VAL_IQC_PACK_LEN_P204                                         2
#define RSSFC_VAL_IQC_PACK_LEN_P208                                         3

// rssfc_rngIqcVsbTestSig
#define RSSFC_VAL_IQC_VSB_TEST_TTSP                                         0

// rssfc_rngAudioBcFmInput
#define RSSFC_VAL_AUDIO_BC_INPUT_OFF                                        0
#define RSSFC_VAL_AUDIO_BC_INPUT_AGEN                                       1
#define RSSFC_VAL_AUDIO_BC_INPUT_MPX                                        2

// rssfc_rngAudioBcFmMode
#define RSSFC_VAL_AUDIO_BC_AF_MODE_LEFT                                     0
#define RSSFC_VAL_AUDIO_BC_AF_MODE_RIGH                                     1
#define RSSFC_VAL_AUDIO_BC_AF_MODE_REL                                      2
#define RSSFC_VAL_AUDIO_BC_AF_MODE_REM                                      3
#define RSSFC_VAL_AUDIO_BC_AF_MODE_RNE                                      4

// rssfc_rngIqcIsdbtTxParam
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_NORM                                    0
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N1                                      1
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N2                                      2
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N3                                      3
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N4                                      4
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N5                                      5
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N6                                      6
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N7                                      7
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N8                                      8
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N9                                      9
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N10                                     10
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N11                                     11
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N12                                     12
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N13                                     13
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N14                                     14
#define RSSFC_IQC_VAL_ISDBT_TXPARAM_N15                                     15

// rssfc_rngAudioBcFmSigType
#define RSSFC_VAL_AUDIO_BC_SIG_TYPE_MONO                                    0
#define RSSFC_VAL_AUDIO_BC_SIG_TYPE_STEREO                                  1

// rssfc_rngAudioBcMoPreemphasis
#define RSSFC_VAL_AUDIO_BC_PREEMPHASIS_OFF                                  0
#define RSSFC_VAL_AUDIO_BC_PREEMPHASIS_D50                                  1
#define RSSFC_VAL_AUDIO_BC_PREEMPHASIS_D75                                  2

// rssfc_rngIqcStuf
#define RSSFC_IQC_STUF_OFF                                                  0
#define RSSFC_IQC_STUF_ON                                                   1
#define RSSFC_IQC_STUF_ONEX                                                 2

// rssfc_rngIqcDirPackLength
#define RSSFC_VAL_IQC_DIR_PACK_LEN_INV                                      0
#define RSSFC_VAL_IQC_DIR_PACK_LEN_P188                                     1

// rssfc_rngIqcDirCons
#define RSSFC_IQC_DIR_CONS_QPSK                                             0

// rssfc_rngIqcDirRollOff
#define RSSFC_VAL_DIR_ROLL_OFF_0_15                                         0
#define RSSFC_VAL_DIR_ROLL_OFF_0_20                                         1
#define RSSFC_VAL_DIR_ROLL_OFF_0_25                                         2
#define RSSFC_VAL_DIR_ROLL_OFF_0_35                                         3

// rssfc_rngIqcDirCodeRate
#define RSSFC_IQC_CRATE_R12                                                 0
#define RSSFC_IQC_CRATE_R23                                                 1
#define RSSFC_IQC_CRATE_R67                                                 2

// rssfc_rngIqcDirTestPacketMode
#define RSSFC_IQC_DIR_TS_MODE_H127                                          0
#define RSSFC_IQC_DIR_TS_MODE_P130                                          1

// rssfc_rngIqcJ83BTestSig
#define RSSFC_VAL_IQC_J83B_TEST_TTSP                                        0
#define RSSFC_VAL_IQC_J83B_TEST_PBEM                                        1

// rssfc_rngIqcJ83BConstellation
#define RSSFC_VAL_IQC_J83B_CONSTEL_J64                                      0
#define RSSFC_VAL_IQC_J83B_CONSTEL_J256                                     1
#define RSSFC_VAL_IQC_J83B_CONSTEL_J1024                                    2

// rssfc_rngIqcJ83BIntrleaverMode
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_0                                    0
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_1                                    1
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_2                                    2
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_3                                    3
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_4                                    4
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_5                                    5
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_6                                    6
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_7                                    7
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_8                                    8
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_9                                    9
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_10                                   10
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_12                                   12
#define RSSFC_VAL_IQC_J83B_INTERLEAVER_14                                   14

// rssfc_rngIqcMfloChanBw
#define RSSFC_IQC_VAL_MFLO_CHBW5                                            0
#define RSSFC_IQC_VAL_MFLO_CHBW6                                            1
#define RSSFC_IQC_VAL_MFLO_CHBW7                                            2
#define RSSFC_IQC_VAL_MFLO_CHBW8                                            3

// rssfc_rngIqcPayload
#define RSSFC_VAL_IQC_PRBS                                                  0
#define RSSFC_VAL_IQC_H00                                                   1
#define RSSFC_VAL_IQC_HFF                                                   2

// rssfc_rngIcqCmmbSour
#define RSSFC_VAL_IQC_CMMB_SOUR_EXT                                         0
#define RSSFC_VAL_IQC_CMMB_SOUR_GEN                                         1
#define RSSFC_VAL_IQC_CMMB_SOUR_TEST                                        2

// rssfc_rngIqcCmmbControl
#define RSSFC_VAL_IQC_CMMB_CONTROL_AUTO                                     0
#define RSSFC_VAL_IQC_CMMB_CONTROL_MANUAL                                   1

// rssfc_rngIqcCmmbBw
#define RSSFC_VAL_IQC_CMMB_BW_2                                             0
#define RSSFC_VAL_IQC_CMMB_BW_8                                             1

// rssfc_rngIqcCmmbOdfm
#define RSSFC_VAL_IQC_CMMB_OFDM_M1K                                         0
#define RSSFC_VAL_IQC_CMMB_OFDM_M4K                                         1

// rssfc_rngIcgAudioFmRdsMs
#define RSSFC_VAL_AUDIO_BC_RDS_MS_MUSIC                                     0
#define RSSFC_VAL_AUDIO_BC_RDS_MS_SPEECH                                    1

// rssfc_rngIcgAudioFmRdsMethod
#define RSSFC_VAL_AUDIO_BC_RDS_AF_METHOD_A                                  0
#define RSSFC_VAL_AUDIO_BC_RDS_AF_METHOD_B                                  1

// rssfc_rngIcgAudioFmAfBOrder
#define RSSFC_VAL_AUDIO_BC_AFB_ORDER_ASC                                    0
#define RSSFC_VAL_AUDIO_BC_AFB_ORDER_DESC                                   1

// rssfc_rngIcgAudioFmEonMethod
#define RSSFC_VAL_AUDIO_BC_EON_METHOD_A                                     0
#define RSSFC_VAL_AUDIO_BC_EON_METHOD_MAPF                                  1

// rssfc_rngIqcIsdbtTmcc
#define RSSFC_IQC_VAL_ISDBT_TMCC_UNUSED                                     0
#define RSSFC_IQC_VAL_ISDBT_TMCC_CURRENT                                    1

// rssfc_rngIqcDvbs2Fecframe
#define RSSFC_VAL_IQC_DVBS2_FECFR_NORMAL                                    0
#define RSSFC_VAL_IQC_DVBS2_FECFR_SHORT                                     1

// rssfc_rngIcqCmmbTstSignal
#define RSSFC_VAL_IQC_CMMB_TST_SIG_CLCHT                                    0
#define RSSFC_VAL_IQC_CMMB_TST_SIG_TONLY                                    1

// rssfc_rngIqcDvbs2Rolloff
#define RSSFC_VAL_DVBS2_ROLL_OFF_0_15                                       0
#define RSSFC_VAL_DVBS2_ROLL_OFF_0_20                                       1
#define RSSFC_VAL_DVBS2_ROLL_OFF_0_25                                       2
#define RSSFC_VAL_DVBS2_ROLL_OFF_0_35                                       3

// rssfc_rngIqcDvbs2CodeRate
#define RSSFC_VAL_IQC_DVBS2_CRATE_14                                        0
#define RSSFC_VAL_IQC_DVBS2_CRATE_13                                        1
#define RSSFC_VAL_IQC_DVBS2_CRATE_25                                        2
#define RSSFC_VAL_IQC_DVBS2_CRATE_12                                        3
#define RSSFC_VAL_IQC_DVBS2_CRATE_35                                        4
#define RSSFC_VAL_IQC_DVBS2_CRATE_23                                        5
#define RSSFC_VAL_IQC_DVBS2_CRATE_34                                        6
#define RSSFC_VAL_IQC_DVBS2_CRATE_45                                        7
#define RSSFC_VAL_IQC_DVBS2_CRATE_56                                        8
#define RSSFC_VAL_IQC_DVBS2_CRATE_67                                        9
#define RSSFC_VAL_IQC_DVBS2_CRATE_78                                        10
#define RSSFC_VAL_IQC_DVBS2_CRATE_89                                        11
#define RSSFC_VAL_IQC_DVBS2_CRATE_910                                       12

// rssfc_rngIqcDvbs2Constel
#define RSSFC_VAL_IQC_DVBS2_CONS_QPSK                                       0
#define RSSFC_VAL_IQC_DVBS2_CONS_8PSK                                       1
#define RSSFC_VAL_IQC_DVBS2_CONS_16APSK                                     2
#define RSSFC_VAL_IQC_DVBS2_CONS_32APSK                                     3

// rssfc_rngAtsmConstel
#define RSSFC_VAL_ATSM_CONS_8VSB                                            0

// rssfc_rngAtsmTestTsPacket
#define RSSFC_VAL_ATSM_TS_PACKET_H184                                       0
#define RSSFC_VAL_ATSM_TS_PACKET_S187                                       1

// rssfc_rngDvbt2MiSource
#define RSSFC_VAL_DVBT2_MI_SOUR_INT                                         0
#define RSSFC_VAL_DVBT2_MI_SOUR_EXT                                         1

// rssfc_rngDvbt2InpFormat
#define RSSFC_VAL_DVBT2_INPUT_FORMAT_TS                                     0
#define RSSFC_VAL_DVBT2_INPUT_FORMAT_GFPS                                   1
#define RSSFC_VAL_DVBT2_INPUT_FORMAT_GCS                                    2
#define RSSFC_VAL_DVBT2_INPUT_FORMAT_GSE                                    3

// rssfc_rngDvbt2PlpType
#define RSSFC_VAL_DVBT2_PLP_TYPE_DT1                                        0
#define RSSFC_VAL_DVBT2_PLP_TYPE_DT2                                        1
#define RSSFC_VAL_DVBT2_PLP_TYPE_COMM                                       2

// rssfc_rngDvbt2BbMode
#define RSSFC_VAL_DVBT2_BB_MODE_HEM                                         0
#define RSSFC_VAL_DVBT2_BB_MODE_NM                                          1

// rssfc_rngDvbt2BicmFec
#define RSSFC_VAL_DVBT2_BICM_FEC_NORMAL                                     0
#define RSSFC_VAL_DVBT2_BICM_FEC_SHORT                                      1

// rssfc_rngDvbt2CRate
#define RSSFC_VAL_IQC_DVBT2_CRATE_R12                                       0
#define RSSFC_VAL_IQC_DVBT2_CRATE_R23                                       1
#define RSSFC_VAL_IQC_DVBT2_CRATE_R34                                       2
#define RSSFC_VAL_IQC_DVBT2_CRATE_R56                                       3
#define RSSFC_VAL_IQC_DVBT2_CRATE_R35                                       4
#define RSSFC_VAL_IQC_DVBT2_CRATE_R45                                       5
#define RSSFC_VAL_IQC_DVBT2_CRATE_R13                                       6
#define RSSFC_VAL_IQC_DVBT2_CRATE_R25                                       7

// rssfc_rngDvbt2Constel
#define RSSFC_VAL_IQC_DVBT2_CONSTEL_T4                                      0
#define RSSFC_VAL_IQC_DVBT2_CONSTEL_T16                                     1
#define RSSFC_VAL_IQC_DVBT2_CONSTEL_T64                                     2
#define RSSFC_VAL_IQC_DVBT2_CONSTEL_T256                                    3

// rssfc_rngDvbt2TimeInt
#define RSSFC_VAL_IQC_DVBT2_TIME_TYPE_T0                                    0
#define RSSFC_VAL_IQC_DVBT2_TIME_TYPE_T1                                    1

// rssfc_rngDvbt2ChBWidth
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_2                                  0
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_5                                  1
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_6                                  2
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_7                                  3
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_8                                  4
#define RSSFC_VAL_IQC_DVBT2_CH_BWIDTH_BW_10                                 5

// rssfc_rngDvbt2FftMode
#define RSSFC_VAL_IQC_DVBT2_FFT_M1K                                         0
#define RSSFC_VAL_IQC_DVBT2_FFT_M2K                                         1
#define RSSFC_VAL_IQC_DVBT2_FFT_M4K                                         2
#define RSSFC_VAL_IQC_DVBT2_FFT_M8K                                         3
#define RSSFC_VAL_IQC_DVBT2_FFT_M8E                                         4
#define RSSFC_VAL_IQC_DVBT2_FFT_M16K                                        5
#define RSSFC_VAL_IQC_DVBT2_FFT_M16E                                        6
#define RSSFC_VAL_IQC_DVBT2_FFT_M32K                                        7
#define RSSFC_VAL_IQC_DVBT2_FFT_M32E                                        8

// rssfc_rngDvbt2GuardInt
#define RSSFC_VAL_IQC_DVBT2_GUARD_G1_4                                      0
#define RSSFC_VAL_IQC_DVBT2_GUARD_G1_8                                      1
#define RSSFC_VAL_IQC_DVBT2_GUARD_G1_16                                     2
#define RSSFC_VAL_IQC_DVBT2_GUARD_G1_32                                     3
#define RSSFC_VAL_IQC_DVBT2_GUARD_G1128                                     4
#define RSSFC_VAL_IQC_DVBT2_GUARD_G19128                                    5
#define RSSFC_VAL_IQC_DVBT2_GUARD_G19256                                    6

// rssfc_rngDvbt2PilotPatt
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP1                                       0
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP2                                       1
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP3                                       2
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP4                                       3
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP5                                       4
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP6                                       5
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP7                                       6
#define RSSFC_VAL_IQC_DVBT2_PILOT_PP8                                       7

// rssfc_rngDvbt2TransSyst
#define RSSFC_VAL_IQC_DVBT2_TRANS_SISO                                      0
#define RSSFC_VAL_IQC_DVBT2_TRANS_MISO                                      1
#define RSSFC_VAL_IQC_DVBT2_TRANS_NONT2                                     2
#define RSSFC_VAL_IQC_DVBT2_TRANS_T2LS                                      3
#define RSSFC_VAL_IQC_DVBT2_TRANS_T2LM                                      4

// rssfc_rngDvbt2PeakAverPow
#define RSSFC_VAL_IQC_DVBT2_PEAK_AVER_POW_OFF                               0
#define RSSFC_VAL_IQC_DVBT2_PEAK_AVER_POW_TR                                1

// rssfc_rngDvbt2L1PostModul
#define RSSFC_VAL_IQC_DVBT2_L_POST_T2                                       0
#define RSSFC_VAL_IQC_DVBT2_L_POST_T4                                       1
#define RSSFC_VAL_IQC_DVBT2_L_POST_T16                                      2
#define RSSFC_VAL_IQC_DVBT2_L_POST_T64                                      3

// rssfc_rngNetworkMode
#define RSSFC_VAL_IQC_NETWORK_MFN                                           0
#define RSSFC_VAL_IQC_NETWORK_SFN                                           1

// rssfc_rngDvbt2MisoGroup
#define RSSFC_VAL_IQC_DVBT2_MISO_G1                                         0
#define RSSFC_VAL_IQC_DVBT2_MISO_G2                                         1

// rssfc_rngDvbt2IssyMode
#define RSSFC_VAL_DVBT2_MODE_ISSY_OFF                                       0
#define RSSFC_VAL_DVBT2_MODE_ISSY_SHORT                                     1
#define RSSFC_VAL_DVBT2_MODE_ISSY_LONG                                      2

// rssfc_rngDvbt2PlpModulType
#define RSSFC_VAL_DVBT2_PLP_MODUL_TYPE_CCM                                  0
#define RSSFC_VAL_DVBT2_PLP_MODUL_TYPE_ACM                                  1

// rssfc_rngDvbt2L1Version
#define RSSFC_VAL_IQC_DVBT2_L_VER_V111                                      0
#define RSSFC_VAL_IQC_DVBT2_L_VER_V121                                      1
#define RSSFC_VAL_IQC_DVBT2_L_VER_V131                                      2

// rssfc_rngMfloIfftMode
#define RSSFC_VAL_MFLO_IFFT_M1K                                             0
#define RSSFC_VAL_MFLO_IFFT_M2K                                             1
#define RSSFC_VAL_MFLO_IFFT_M4K                                             2
#define RSSFC_VAL_MFLO_IFFT_M8K                                             3

// rssfc_rngMfloStimMap
#define RSSFC_VAL_MFLO_STIM_MAP_1                                           0
#define RSSFC_VAL_MFLO_STIM_MAP_2                                           1
#define RSSFC_VAL_MFLO_STIM_MAP_3                                           2

// rssfc_rngMfloCPLength
#define RSSFC_VAL_MFLO_CPR_LENGTH_G1_16                                     0
#define RSSFC_VAL_MFLO_CPR_LENGTH_G1_8                                      1
#define RSSFC_VAL_MFLO_CPR_LENGTH_G3_16                                     2
#define RSSFC_VAL_MFLO_CPR_LENGTH_G1_4                                      3

// rssfc_rngIqcIsdbtControl
#define RSSFC_VAL_IQC_ISDBT_CONTROL_AUTO                                    0
#define RSSFC_VAL_IQC_ISDBT_CONTROL_MANUAL                                  1

// rssfc_rngCodingControl
#define RSSFC_VAL_IQC_CONTROL_MODE_AUTO                                     0
#define RSSFC_VAL_IQC_CONTROL_MODE_MANUAL                                   1

// rssfc_rngDvbc2InpFormat
#define RSSFC_VAL_DVBC2_INPUT_FORMAT_TS                                     0

// rssfc_rngDvbc2PlpType
#define RSSFC_VAL_DVBC2_PLP_TYPE_NORMAL                                     0
#define RSSFC_VAL_DVBC2_PLP_TYPE_COMMON                                     1
#define RSSFC_VAL_DVBC2_PLP_TYPE_GROUPED                                    2

// rssfc_rngDvbc2BbMode
#define RSSFC_VAL_DVBC2_BB_MODE_HEM                                         0
#define RSSFC_VAL_DVBC2_BB_MODE_NM                                          1

// rssfc_rngDvbc2IssyMode
#define RSSFC_VAL_DVBC2_MODE_ISSY_OFF                                       0
#define RSSFC_VAL_DVBC2_MODE_ISSY_SHORT                                     1
#define RSSFC_VAL_DVBC2_MODE_ISSY_LONG                                      2

// rssfc_rngDvbc2BicmFec
#define RSSFC_VAL_DVBC2_BICM_FEC_NORMAL                                     0
#define RSSFC_VAL_DVBC2_BICM_FEC_SHORT                                      1

// rssfc_rngDvbc2CodeRate
#define RSSFC_VAL_IQC_DVBC2_CRATE_R2_3                                      0
#define RSSFC_VAL_IQC_DVBC2_CRATE_R3_4                                      1
#define RSSFC_VAL_IQC_DVBC2_CRATE_R4_5                                      2
#define RSSFC_VAL_IQC_DVBC2_CRATE_R5_6                                      3
#define RSSFC_VAL_IQC_DVBC2_CRATE_R8_9                                      4
#define RSSFC_VAL_IQC_DVBC2_CRATE_R9_10                                     5

// rssfc_rngDvbc2Constell
#define RSSFC_VAL_IQC_CONSTEL_Q16                                           0
#define RSSFC_VAL_IQC_CONSTEL_Q64                                           1
#define RSSFC_VAL_IQC_CONSTEL_Q256                                          2
#define RSSFC_VAL_IQC_CONSTEL_Q1024                                         3
#define RSSFC_VAL_IQC_CONSTEL_Q4096                                         4

// rssfc_rngDvbc2DslTIDepth
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_0                               0
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_4                               1
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_8                               2
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TI_DEPTH_16                              3

// rssfc_rngDvbc2DslType
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TYPE_1                                   0
#define RSSFC_VAL_IQC_DVBC2_DSLICE_TYPE_2                                   1

// rssfc_rngDvbc2DslFecHeaderType
#define RSSFC_VAL_IQC_DVBC2_DSLICE_FEC_HEADER_ROBUST                        0
#define RSSFC_VAL_IQC_DVBC2_DSLICE_FEC_HEADER_HEM                           1

// rssfc_rngDvbc2ChBWidth
#define RSSFC_VAL_IQC_DVBC2_CHANNEL_BW_6                                    0
#define RSSFC_VAL_IQC_DVBC2_CHANNEL_BW_8                                    1

// rssfc_rngDvbc2GuardInt
#define RSSFC_VAL_IQC_DVBC2_GUARD_1_64                                      0
#define RSSFC_VAL_IQC_DVBC2_GUARD_1_128                                     1

// rssfc_rngDvbc2SystemInterleaver
#define RSSFC_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_OFF                          0
#define RSSFC_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_BEST                         1
#define RSSFC_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_FOUR                         2
#define RSSFC_VAL_IQC_DVBC2_SYSTEM_INTERLEAVER_EIGHT                        3

// rssfc_rngDVBC2NotchType
#define RSSFC_VAL_DVBC2_NOTCT_TYPE_NARROW                                   0
#define RSSFC_VAL_DVBC2_NOTCT_TYPE_BROAD                                    1

// rssfc_rngDVBC2FramingBasebandFilter
#define RSSFC_VAL_IQC_DVBC2_BB_FILTER_FIR                                   0
#define RSSFC_VAL_IQC_DVBC2_BB_FILTER_G1_4                                  1
#define RSSFC_VAL_IQC_DVBC2_BB_FILTER_G1_2                                  2
#define RSSFC_VAL_IQC_DVBC2_BB_FILTER_G3_4                                  3
#define RSSFC_VAL_IQC_DVBC2_BB_FILTER_G1_1                                  4

// rssfc_rngDVBT2T2SystemProfileMode
#define RSSFC_VAL_IQC_DVBT2_PROFILE_SINGLE                                  0
#define RSSFC_VAL_IQC_DVBT2_PROFILE_MULTI                                   1

// rssfc_rngDVBT2SFNTimestampMode
#define RSSFC_VAL_DVBT2_SFN_TIMESTAMP_MODE_REL                              0
#define RSSFC_VAL_DVBT2_SFN_TIMESTAMP_MODE_ABS                              1

// rssfc_rngDVBT2T2SystemFutureExtensionFramesPayload
#define RSSFC_VAL_IQC_DVBT2_FEF_PAYLOAD_NULL                                0
#define RSSFC_VAL_IQC_DVBT2_FEF_PAYLOAD_NOISE                               1
/* END GENERATE */  

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSSFC_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSSFC_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSSFC_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSSFC_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */


/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/
    
#define RSSFC_SWEEP_START       0
#define RSSFC_SWEEP_CENTER      1

#define RSSFC_VAL_PRIORITY_HIGH     0
#define RSSFC_VAL_PRIORITY_LOW      1
#define RSSFC_VAL_PRIORITY_NONE     2

   
#define RSSFC_VAL_PACKET_LENGTH     0
#define RSSFC_VAL_MAX_USEFUL_DRATE  1
#define RSSFC_VAL_MEAS_USEFUL_DRATE 2
#define RSSFC_VAL_MEAS_DRATE        2
#define RSSFC_VAL_USEFUL_DRATE      3
#define RSSFC_VAL_MEAS_TS_DRATE     4

#define RSSFC_VAL_CAL_ALL               0
#define RSSFC_VAL_CAL_VML               1
#define RSSFC_VAL_CAL_VMF               2

#define RSSFC_VAL_SIGN_TIMESTAMP        0
#define RSSFC_VAL_MAX_DELAY             1
#define RSSFC_VAL_LOC_DELAY             2
#define RSSFC_VAL_ADD_DELAY             3

#define RSSFC_VAL_TDMB_NUM_STREAMS      0
#define RSSFC_VAL_TDMB_MODE_IDENTITY    1

#define RSSFC_VAL_MMEM_COPY             0
#define RSSFC_VAL_MMEM_DELETE           1
#define RSSFC_VAL_MMEM_RENAME           2
#define RSSFC_VAL_MMEM_MDIR             3
#define RSSFC_VAL_MMEM_CDIR             4
#define RSSFC_VAL_MMEM_RDIR             5
#define RSSFC_VAL_MMEM_MSIS             6

#define RSSFC_VAL_MMEM_CATALOG_FILES    0
#define RSSFC_VAL_MMEM_CATALOG_SUBDIR   1

#define RSSFC_ARB_VAL_TRIGGER_ARM               0
#define RSSFC_ARB_VAL_TRIGGGER_EXECUTE          1

#define RSSFC_VAL_FREQ_CHAN_TAB_SELECT          0
#define RSSFC_VAL_FREQ_CHAN_TAB_STORE           1
#define RSSFC_VAL_FREQ_CHAN_TAB_DELETE          2


#define RSSFC_VAL_PRESET_STAT_REG               0
#define RSSFC_VAL_QUEST_STAT_REG                1
#define RSSFC_VAL_OPER_STAT_REG                 2

#define RSSFC_VAL_REG_CONDITION                 0
#define RSSFC_VAL_REG_EVENT                     1
#define RSSFC_VAL_REG_ENABLE                    2
#define RSSFC_VAL_REG_PTRANSITION               3
#define RSSFC_VAL_REG_NTRANSITION               4

#define RSSFC_VAL_ARB_WF_TAG_TYPE               0
#define RSSFC_VAL_ARB_WF_TAG_CRESTFACTOR        1       
#define RSSFC_VAL_ARB_WF_TAG_LEVEL_OFFS         2
#define RSSFC_VAL_ARB_WF_TAG_CLOCK              3
#define RSSFC_VAL_ARB_WF_TAG_SAMPLES            4   
#define RSSFC_VAL_ARB_WF_TAG_IQ_SWAP            5
#define RSSFC_VAL_ARB_WF_TAG_DATE               6
#define RSSFC_VAL_ARB_WF_TAG_COMMENT            7

#define RSSFC_VAL_SAVE                          0
#define RSSFC_VAL_RECALL                        1
#define RSSFC_VAL_DELETE						2

#define RSSFC_VAL_IQC_ISDBT_LAYER_A     0
#define RSSFC_VAL_IQC_ISDBT_LAYER_B     1
#define RSSFC_VAL_IQC_ISDBT_LAYER_C     2

#define RSSFC_VAL_ATV_SOUND_FREQ_DEV_MONO    0
#define RSSFC_VAL_ATV_SOUND_FREQ_DEV_SUBCAR1 1
#define RSSFC_VAL_ATV_SOUND_FREQ_DEV_SUBCAR2 2
#define RSSFC_VAL_ATV_SOUND_FREQ_DEV_PILOT   3

#define RSSFC_VAL_ATV_SOUND_SPEC_SUBCAR_MONO  0
#define RSSFC_VAL_ATV_SOUND_SPEC_SUBCAR1      1
#define RSSFC_VAL_ATV_SOUND_SPEC_SUBCAR2      2

#define RSSFC_VAL_ATV_AUDIO_SOUND_FREQ_MONO     0
#define RSSFC_VAL_ATV_AUDIO_SOUND_FREQ_LEFT     1
#define RSSFC_VAL_ATV_AUDIO_SOUND_FREQ_RIGHT    2
#define RSSFC_VAL_ATV_AUDIO_SOUND_FREQ_CH1      3
#define RSSFC_VAL_ATV_AUDIO_SOUND_FREQ_CH2      4

#define RSSFC_VAL_ATV_AUDIO_SOUND_LEVEL_MONO    0
#define RSSFC_VAL_ATV_AUDIO_SOUND_LEVEL_LEFT    1
#define RSSFC_VAL_ATV_AUDIO_SOUND_LEVEL_RIGHT   2
#define RSSFC_VAL_ATV_AUDIO_SOUND_LEVEL_CH1     3
#define RSSFC_VAL_ATV_AUDIO_SOUND_LEVEL_CH2     4

#define RSSFC_VAL_ATV_AUDIO_GEN_AF1             0
#define RSSFC_VAL_ATV_AUDIO_GEN_AF2             1
    
#define RSSFC_VAL_MOD_DIG_IO_INP_RMS            0
#define RSSFC_VAL_MOD_DIG_IO_INP_PEAK           1
                                                
#define RSSFC_VAL_MOD_IQ_INPUT_DIG              0
    
#define RSSFC_VAL_REQ_SOURCE_DRATE              0
    

#define RSSFC_VAL_BER_STOP                      0
#define RSSFC_VAL_BER_START                     1
#define RSSFC_VAL_BER_RESTART                   2
    
#define RSSFC_VAL_BER_BER                       0
#define RSSFC_VAL_BER_EVAL                      1
#define RSSFC_VAL_BER_STATE                     2
#define RSSFC_VAL_BER_ERROR_COUNT               3
#define RSSFC_VAL_BER_GATING_TIME               4
#define RSSFC_VAL_BER_ALL                       5


#define RSSFC_VAL_MFLO_MEAS_DRATE    0
#define RSSFC_VAL_MFLO_MEAS_WID_COND 1
#define RSSFC_VAL_MFLO_MEAS_WID_CTRD 2
#define RSSFC_VAL_MFLO_MEAS_WID_OIS  3
#define RSSFC_VAL_MFLO_MEAS_LID_COND 4
#define RSSFC_VAL_MFLO_MEAS_LID_CTRD 5
#define RSSFC_VAL_MFLO_MEAS_LID_OIS  6

#define RSSFC_VAL_IQC_MFLO_WIDE_PID  0
#define RSSFC_VAL_IQC_MFLO_LOCAL_PID 1

#define RSSFC_VAL_MFLO_STATUS_SSF_TIME 0
#define RSSFC_VAL_MFLO_STATUS_PPS_TDM  1

#define RSSFC_VAL_MFLO_STATUS_OUTF_COUNT 0
#define RSSFC_VAL_MFLO_STATUS_SEER_COUNT 1
#define RSSFC_VAL_MFLO_STATUS_SCER_COUNT 2

#define RSSFC_VAL_AUDIO_BC_SOUR_LEFT            0
#define RSSFC_VAL_AUDIO_BC_SOUR_RIGHT           1
#define RSSFC_VAL_AUDIO_BC_SOUR_MPX             2  
     
#define RSSFC_VAL_AUDIO_FREQ_DEV_AUDIO          0
#define RSSFC_VAL_AUDIO_FREQ_DEV_MPX            1


#define RSSFC_VAL_IQC_CMMB_RS_0   0
#define RSSFC_VAL_IQC_CMMB_RS_1   1
#define RSSFC_VAL_IQC_CMMB_RS_2   2
#define RSSFC_VAL_IQC_CMMB_RS_3   3
    
#define RSSFC_VAL_IQC_CMMB_LDPC_R1_2  0
#define RSSFC_VAL_IQC_CMMB_LDPC_R3_4  1

#define RSSFC_VAL_IQC_CMMB_CONST_C2  0
#define RSSFC_VAL_IQC_CMMB_CONST_C4  1
#define RSSFC_VAL_IQC_CMMB_CONST_C16 2

#define RSSFC_VAL_AUDIO_BC_OF_GROUP_A   0
#define RSSFC_VAL_AUDIO_BC_OF_GROUP_B   1

#define RSSFC_VAL_FADING_STANDARD 0
	
#define RSSFC_VAL_FADING_PATH_LOSS     0
#define RSSFC_VAL_FADING_BASIC_DELAY   1
#define RSSFC_VAL_FADING_ADD_DELAY     2
#define RSSFC_VAL_FADING_POWER_RATIO   3
#define RSSFC_VAL_FADING_CONST_PHASE   4
#define RSSFC_VAL_FADING_SPEED         5
#define RSSFC_VAL_FADING_FREQ_RATIO    6

#define RSSFC_VAL_FADING_RES_DELAY      0
#define RSSFC_VAL_FADING_RES_DOPP_SHIFT 1

#define RSSFC_VAL_IQC_DVBT2_FEC_BLOCK     0
#define RSSFC_VAL_IQC_DVBT2_FEC_MAX_BLOCK 1

#define RSSFC_VAL_DVBC2_NOTCH_START_REL    0
#define RSSFC_VAL_DVBC2_NOTCH_STOP_REL     1
#define RSSFC_VAL_DVBC2_NOTCH_WIDTH        2
#define RSSFC_VAL_DVBC2_NOTCH_START_ABS    3
#define RSSFC_VAL_DVBC2_NOTCH_STOP_ABS     4

#define RSSFC_VAL_DVBC2_NOTCH_START_FREQ   0
#define RSSFC_VAL_DVBC2_NOTCH_STOP_FREQ    1

#define RSSFC_VAL_DVBC2_DSLICE_START_REL    0
#define RSSFC_VAL_DVBC2_DSLICE_STOP_REL     1
#define RSSFC_VAL_DVBC2_DSLICE_WIDTH        2
#define RSSFC_VAL_DVBC2_DSLICE_START_ABS    3
#define RSSFC_VAL_DVBC2_DSLICE_STOP_ABS     4
#define RSSFC_VAL_DVBC2_DSLICE_TUNE_POS_ABS 5 
#define RSSFC_VAL_DVBC2_DSLICE_TUNE_POS_REL 6


#define RSSFC_VAL_DVBC2_DSLICE_TUNE_FREQ 	 0
#define RSSFC_VAL_DVBC2_DSLICE_START_FREQ    1
#define RSSFC_VAL_DVBC2_DSLICE_STOP_FREQ     2



#define RSSFC_VAL_DVBT2_SFN_MAX_DEVIATION_TIME 	0
#define RSSFC_VAL_DVBT2_SFN_STATIC_DELAY       	1
#define RSSFC_VAL_DVBT2_SFN_DYNAMIC_DELAY      	2
#define RSSFC_VAL_DVBT2_SFN_TOTAL_DELAY        	3
#define RSSFC_VAL_DVBT2_SFN_PROCESS_DELAY     	4

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
    
ViStatus _VI_FUNC rssfc_init (ViRsrc resourceName, ViBoolean IDQuery,
                              ViBoolean resetDevice, ViPSession instrumentHandle);
ViStatus _VI_FUNC rssfc_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                         ViBoolean resetDevice,
                                         ViString optionString,
                                         ViPSession instrumentHandle);
ViStatus _VI_FUNC rssfc_confTxFreq (ViSession instrumentHandle, ViReal64 frequency);
ViStatus _VI_FUNC rssfc_SetTxActualCenterFrequency (ViSession instrumentHandle,
                                                    ViReal64 RFOutputFrequency);
ViStatus _VI_FUNC rssfc_SetTxFrequencyChannel (ViSession instrumentHandle,
                                               ViInt32 frequencyChannel);
ViStatus _VI_FUNC rssfc_FrequencyChannelTableOperations (ViSession instrumentHandle,
                                                         ViInt32 operation,
                                                         ViString channelName);
ViStatus _VI_FUNC rssfc_ConfigureChannelTableFrequency (ViSession instrumentHandle,
                                                        ViInt32 channel,
                                                        ViString channelName,
                                                        ViReal64 channelFrequency);
ViStatus _VI_FUNC rssfc_SetFrequencyVSBReferencePoint (ViSession instrumentHandle,
                                                       ViInt32 frequencyReferencePoint);
ViStatus _VI_FUNC rssfc_readTxFreq (ViSession instrumentHandle,
                                    ViPReal64 TXFrequency);
ViStatus _VI_FUNC rssfc_confTxLevel (ViSession instrumentHandle, ViReal64 level,
                                     ViBoolean RF, ViReal64 userLimit,
                                     ViInt32 attenuatorMode, ViInt32 levelUnit);
ViStatus _VI_FUNC rssfc_readTxLevel (ViSession instrumentHandle, ViPReal64 TXLevel);
ViStatus _VI_FUNC rssfc_getTxAttFixedRange (ViSession instrumentHandle,
                                            ViPReal64 lower, ViPReal64 upper);
ViStatus _VI_FUNC rssfc_readPeakEnvelopePower (ViSession instrumentHandle,
                                               ViPReal64 peakEnvelopePower);
ViStatus _VI_FUNC rssfc_confTxModulation (ViSession instrumentHandle,
                                          ViBoolean modulation,
                                          ViInt32 signalSource,
                                          ViInt32 transmissionStandard,
                                          ViInt32 spectrum);
ViStatus _VI_FUNC rssfc_confAtvTransStandard (ViSession instrumentHandle,
                                              ViInt32 ATVTransmissionStandard);
ViStatus _VI_FUNC rssfc_confTxModulationSettings (ViSession instrumentHandle,
                                                  ViInt32 iQDigitalInMode);
ViStatus _VI_FUNC rssfc_confAudioStandard (ViSession instrumentHandle,
                                           ViInt32 audioStandard);
ViStatus _VI_FUNC rssfc_setModulationIQSwap (ViSession instrumentHandle,
                                             ViBoolean IQSwap);
ViStatus _VI_FUNC rssfc_readModulationSigInfoStat (ViSession instrumentHandle,
                                                   ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_confTxModIqInputRefresh (ViSession instrumentHandle,
                                                 ViInt32 refresh);
ViStatus _VI_FUNC rssfc_readDigitalIqSymbolRate (ViSession instrumentHandle,
                                                 ViPReal64 IQSymbolRate);
ViStatus _VI_FUNC rssfc_confDVBTInputSignal (ViSession instrumentHandle,
                                             ViInt32 priorityPath, ViInt32 source,
                                             ViInt32 input, ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confDVBTTestSignal (ViSession instrumentHandle,
                                            ViInt32 priorityPath,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDVBTValues (ViSession instrumentHandle,
                                        ViInt32 priorityPath, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDVBTCoding (ViSession instrumentHandle,
                                        ViInt32 channelBandwidth, ViInt32 FFTMode,
                                        ViInt32 guardInterval, ViInt32 hierarchy,
                                        ViInt32 constellation);
ViStatus _VI_FUNC rssfc_confDVBTCodeRate (ViSession instrumentHandle,
                                          ViInt32 priorityPath, ViInt32 codeRate);
ViStatus _VI_FUNC rssfc_confDVBHCoding (ViSession instrumentHandle, ViBoolean state,
                                        ViInt32 symbolInterleaverMode);
ViStatus _VI_FUNC rssfc_actEnableDVBTSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfc_confDVBTSpecial (ViSession instrumentHandle,
                                         ViInt32 priorityPath,
                                         ViBoolean reedSolomon);
ViStatus _VI_FUNC rssfc_confDVBTPacketsPayload (ViSession instrumentHandle,
                                                ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureDVBTPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTest);
ViStatus _VI_FUNC rssfc_confDVBTTPS (ViSession instrumentHandle, ViInt32 TPSCellID,
                                     ViBoolean TPSResevedState,
                                     ViInt32 TPSReservedValue);
ViStatus _VI_FUNC rssfc_confDVBTTimeMPE (ViSession instrumentHandle,
                                         ViInt32 priorityPath,
                                         ViBoolean timeSlicing, ViBoolean MPEFEC);
ViStatus _VI_FUNC rssfc_confDVBCInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confDVBCTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDVBCPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readDVBCValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDVBCCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 rollOff);
ViStatus _VI_FUNC rssfc_actEnableDVBCSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfc_confDVBCSpecialReedSolomon (ViSession instrumentHandle,
                                                    ViBoolean reedSolomon);
ViStatus _VI_FUNC rssfc_confDVBCSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureDVBCPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confDVBSInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confDVBSTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDVBSPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readDVBSValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDVBSCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 rollOff, ViInt32 codeRate);
ViStatus _VI_FUNC rssfc_actEnableDVBSSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfc_confDVBSSpecialReedSolomon (ViSession instrumentHandle,
                                                    ViBoolean reedSolomon);
ViStatus _VI_FUNC rssfc_confDVBSSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureDVBSPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_conf8VSBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_conf8VSBTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_read8VSBPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_read8VSBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_set8VSBSymbolRate (ViSession instrumentHandle,
                                           ViReal64 symbolRate);
ViStatus _VI_FUNC rssfc_read8VSBConstellation (ViSession instrumentHandle,
                                               ViChar _VI_FAR constellation[]);
ViStatus _VI_FUNC rssfc_read8VSBRollOff (ViSession instrumentHandle,
                                         ViPReal64 rollOff);
ViStatus _VI_FUNC rssfc_conf8VSBSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_Configure8VSBPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confJ83BInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfc_confJ83BTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readJ83BPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readJ83BValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confJ83BCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViInt32 constellation,
                                        ViInt32 interleaver);
ViStatus _VI_FUNC rssfc_readJ83BRollOff (ViSession instrumentHandle,
                                         ViPReal64 rollOff);
ViStatus _VI_FUNC rssfc_actEnableJ83BSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfc_confJ83BSpecialReedSolomon (ViSession instrumentHandle,
                                                    ViBoolean reedSolomon);
ViStatus _VI_FUNC rssfc_confJ83BSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureJ83BPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confISDBTInputSource (ViSession instrumentHandle,
                                              ViInt32 layer, ViInt32 source);
ViStatus _VI_FUNC rssfc_confISDBTInputSignal (ViSession instrumentHandle,
                                              ViInt32 input, ViBoolean remux,
                                              ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confISDBTTestSignal (ViSession instrumentHandle,
                                             ViInt32 layer, ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readISDBTInputDataRate (ViSession instrumentHandle,
                                                ViPReal64 inputDataRate);
ViStatus _VI_FUNC rssfc_readISDBTValues (ViSession instrumentHandle, ViInt32 layer,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_confISDBTSystem (ViSession instrumentHandle,
                                         ViInt32 ISDBTSystem);
ViStatus _VI_FUNC rssfc_ConfigureISDBTControl (ViSession instrumentHandle,
                                               ViInt32 control);
ViStatus _VI_FUNC rssfc_confISDBTLayerCoding (ViSession instrumentHandle,
                                              ViInt32 portion, ViInt32 layer,
                                              ViInt32 constellation,
                                              ViInt32 codeRate,
                                              ViInt32 timeInterleaving);
ViStatus _VI_FUNC rssfc_confISDBTCoding (ViSession instrumentHandle,
                                         ViInt32 ISDBTMode, ViInt32 guardInterval);
ViStatus _VI_FUNC rssfc_confISDBTSubChannel (ViSession instrumentHandle,
                                             ViInt32 subChannel);
ViStatus _VI_FUNC rssfc_confISDBTSegments (ViSession instrumentHandle,
                                           ViInt32 layer, ViInt32 segments);
ViStatus _VI_FUNC rssfc_readISDBTBandwidth (ViSession instrumentHandle,
                                            ViPReal64 bandwidth);
ViStatus _VI_FUNC rssfc_actEnableISDBTSpecial (ViSession instrumentHandle,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfc_confISDBTSpecialAcDataSettings (ViSession instrumentHandle,
                                                        ViInt32 ACData_AC1,
                                                        ViInt32 ACData_AC2);
ViStatus _VI_FUNC rssfc_EnableISDBTSpecialAlertBroadcast (ViSession instrumentHandle,
                                                          ViBoolean state);
ViStatus _VI_FUNC rssfc_ConfigureISDBTSpecialSettings (ViSession instrumentHandle,
                                                       ViBoolean residualCarrierShift,
                                                       ViInt32 TXParamSwitchingIndicator,
                                                       ViInt32 TMCCNext);
ViStatus _VI_FUNC rssfc_confISDBTSettings (ViSession instrumentHandle,
                                           ViInt32 layer, ViInt32 testTSPacket,
                                           ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureISDBTPayloadTestStuff (ViSession instrumentHandle,
                                                        ViInt32 layer,
                                                        ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confDVBS2InputSignal (ViSession instrumentHandle,
                                              ViInt32 source, ViInt32 input,
                                              ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confDVBS2TestSignal (ViSession instrumentHandle,
                                             ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDVBS2PackedLength (ViSession instrumentHandle,
                                               ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readDVBS2Values (ViSession instrumentHandle, ViInt32 value,
                                         ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDVBS2Coding (ViSession instrumentHandle,
                                         ViReal64 symbolRate, ViInt32 constellation,
                                         ViInt32 FECFrame, ViBoolean pilots,
                                         ViInt32 rollOff, ViInt32 codeRate);
ViStatus _VI_FUNC rssfc_confDVBS2Settings (ViSession instrumentHandle,
                                           ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confDVBS2PayloadTestStuff (ViSession instrumentHandle,
                                                   ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confDirectvInputSignal (ViSession instrumentHandle,
                                                ViInt32 source, ViInt32 input,
                                                ViInt32 stuffing,
                                                ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDirectvPackedLength (ViSession instrumentHandle,
                                                 ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readDirectvValues (ViSession instrumentHandle,
                                           ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDirectvCoding (ViSession instrumentHandle,
                                           ViReal64 symbolRate,
                                           ViInt32 constellation, ViInt32 rollOff,
                                           ViInt32 codeRate);
ViStatus _VI_FUNC rssfc_confDirectvSettings (ViSession instrumentHandle,
                                             ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confMfloInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input);
ViStatus _VI_FUNC rssfc_ReadMediaFLOValues (ViSession instrumentHandle,
                                            ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_ReadStatusMediaFLODelayParameters
             (ViSession instrumentHandle, ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_ReadStatusMediaFLOCountParameters
             (ViSession instrumentHandle, ViInt32 value, ViPInt32 result);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOCoding (ViSession instrumentHandle,
                                                 ViInt32 channelBandwidth,
                                                 ViInt32 IFFTMode,
                                                 ViInt32 slotToInterlaceMapping,
                                                 ViInt32 cyclicPrefixLength);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOCodingParameters
             (ViSession instrumentHandle, ViInt32 wideAreaIDValue,
              ViInt32 localAreaIDValue, ViInt32 wideMACSymbolsFrame,
              ViInt32 localMACSymbolsFrame, ViReal64 networkGeographyDelay);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOPIDSettings (ViSession instrumentHandle,
                                                      ViInt32 PID, ViInt32 content,
                                                      ViInt32 controlChannel,
                                                      ViInt32 OIS);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOLocalOISSystemSettings
             (ViSession instrumentHandle, ViBoolean localOISInsertion,
              ViInt32 infrastructureID, ViReal64 localTimeOffset,
              ViBoolean daylightSavingTimeIndicator);
ViStatus _VI_FUNC rssfc_EnableMediaFLOPositionPilotSettings
             (ViSession instrumentHandle, ViBoolean positionPilotSymbols);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOPositionPilotTransmitterSettings
             (ViSession instrumentHandle, ViInt32 transmitterID,
              ViInt32 numberOfTransmitters);
ViStatus _VI_FUNC rssfc_EnableMediaFLOTXPositionSettings (ViSession instrumentHandle,
                                                          ViBoolean TXPositionEnable,
                                                          ViInt32 TXPosition);
ViStatus _VI_FUNC rssfc_ConfigureMediaFLOTXSettings (ViSession instrumentHandle,
                                                     ViBoolean TXOffsetEnable,
                                                     ViReal64 TXOffset,
                                                     ViReal64 TXLatitude,
                                                     ViReal64 TXLongitude,
                                                     ViReal64 TXAltitude);
ViStatus _VI_FUNC rssfc_confTDMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source);
ViStatus _VI_FUNC rssfc_readTDMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPInt32 result);
ViStatus _VI_FUNC rssfc_readTDMBEtiInput (ViSession instrumentHandle,
                                          ViPInt32 ETIInput);
ViStatus _VI_FUNC rssfc_readTDMBInfo (ViSession instrumentHandle,
                                      ViInt32 subChannel, ViPInt32 SCID,
                                      ViPInt32 protProfile, ViPInt32 protLevel,
                                      ViPInt32 dataRate);
ViStatus _VI_FUNC rssfc_actEnableTDMBSpecial (ViSession instrumentHandle,
                                              ViBoolean state);
ViStatus _VI_FUNC rssfc_confTDMBSpecial (ViSession instrumentHandle,
                                         ViInt32 transmissionMode,
                                         ViInt32 selectTransmissionMode,
                                         ViBoolean PRBSTestsignal,
                                         ViInt32 testsignalSCID);
ViStatus _VI_FUNC rssfc_confTDMBConfiguration (ViSession instrumentHandle,
                                               ViBoolean TDMBTTI, ViInt32 TIIMainID,
                                               ViInt32 TIISubID, ViInt32 TDMBPRBS);
ViStatus _VI_FUNC rssfc_confDTMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confDTMBTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readDTMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDTMBNetworkMode (ViSession instrumentHandle,
                                             ViInt32 networkMode,
                                             ViBoolean singleCarrierMode,
                                             ViBoolean controlFrames,
                                             ViBoolean dualPilotTone);
ViStatus _VI_FUNC rssfc_confDTMBControl (ViSession instrumentHandle,
                                         ViInt32 channelBandwidth);
ViStatus _VI_FUNC rssfc_confDTMBCoding (ViSession instrumentHandle,
                                        ViInt32 constellation, ViInt32 codeRate,
                                        ViInt32 guardInterval,
                                        ViInt32 guardIntervalPN,
                                        ViInt32 timeInterleaver);
ViStatus _VI_FUNC rssfc_confDTMBSettings (ViSession instrumentHandle,
                                          ViInt32 testTSPacket, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_ConfigureDTMBPayloadTestStuff (ViSession instrumentHandle,
                                                       ViInt32 payloadTestStuff);
ViStatus _VI_FUNC rssfc_confCMMBInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViInt32 stuffing);
ViStatus _VI_FUNC rssfc_configureCMMBTestSignal (ViSession instrumentHandle,
                                                 ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readCMMBValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_SetCMMBNumberOfServices (ViSession instrumentHandle,
                                                 ViInt32 numberOfServices);
ViStatus _VI_FUNC rssfc_confCMMBCoding (ViSession instrumentHandle, ViInt32 control,
                                        ViInt32 bandwidth);
ViStatus _VI_FUNC rssfc_ReadCMMBOFDMMode (ViSession instrumentHandle,
                                          ViPInt32 OFDMMode);
ViStatus _VI_FUNC rssfc_confCMMBPLCHTable (ViSession instrumentHandle, ViInt32 PLCH,
                                           ViInt32 RS, ViInt32 byteIL, ViInt32 LDPC,
                                           ViInt32 constel, ViInt32 SCRMode,
                                           ViInt32 startTS, ViInt32 stopTS);
ViStatus _VI_FUNC rssfc_confCMMBSettings (ViSession instrumentHandle,
                                          ViInt32 transmitterID, ViInt32 areaID,
                                          ViInt32 payloadTestSignal, ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confDVBT2InputSignal (ViSession instrumentHandle,
                                              ViBoolean t2MIInterface,
                                              ViInt32 t2MISource,
                                              ViInt32 numberOfPLP,
                                              ViInt32 t2MIInput);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2InputT2MIPID (ViSession instrumentHandle,
                                                    ViInt32 t2MIPID);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2InputT2MISID (ViSession instrumentHandle,
                                                    ViInt32 t2MISID);
ViStatus _VI_FUNC rssfc_ResetDVBT2T2MIAnalyzerLogFile (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_ReadDVBT2T2MIAnalyzer (ViSession instrumentHandle,
                                               ViChar _VI_FAR t2MIAnalyzer[]);
ViStatus _VI_FUNC rssfc_configureDVBT2Plp (ViSession instrumentHandle, ViInt32 PLP,
                                           ViInt32 inputFormat, ViInt32 source,
                                           ViInt32 input, ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_readDVBT2Values (ViSession instrumentHandle, ViInt32 PLP,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_confDVBT2TestSignal (ViSession instrumentHandle,
                                             ViInt32 PLP, ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_confDVBT2ModeStreamAdaptation (ViSession instrumentHandle,
                                                       ViInt32 PLP, ViInt32 PLPID,
                                                       ViInt32 PLPType,
                                                       ViInt32 BBMode, ViInt32 ISSY,
                                                       ViBoolean nullPacketDel,
                                                       ViBoolean inBandSignal,
                                                       ViInt32 CMType);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2ModeStreamAdaptationInBandSignal
             (ViSession instrumentHandle, ViInt32 PLP, ViBoolean inBandSignalA,
              ViBoolean inBandSignalB);
ViStatus _VI_FUNC rssfc_ReadDVBT2ModeStreamAdaptationValues
             (ViSession instrumentHandle, ViInt32 PLP, ViPInt32 PLPGroupID,
              ViPInt32 otherInBandPLP);
ViStatus _VI_FUNC rssfc_confDVBT2BICMParameters (ViSession instrumentHandle,
                                                 ViInt32 PLP, ViInt32 FECFrame,
                                                 ViInt32 codeRate,
                                                 ViInt32 constellation,
                                                 ViBoolean constellRotation);
ViStatus _VI_FUNC rssfc_confDVBT2BICMTimeInterleaverParameters
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 timeInterleaverType,
              ViInt32 frameIntIJump, ViInt32 timeInterleaverLength);
ViStatus _VI_FUNC rssfc_readDVBT2BICMFECBlocksPerIF (ViSession instrumentHandle,
                                                     ViInt32 PLP, ViInt32 block,
                                                     ViPInt32 value);
ViStatus _VI_FUNC rssfc_confDVBT2BICMFramingOFDMParameters
             (ViSession instrumentHandle, ViInt32 channelBandwidth,
              ViInt32 bandwidthVariation, ViInt32 FFTSize, ViInt32 guardInterval,
              ViInt32 pilotPattern);
ViStatus _VI_FUNC rssfc_readDVBT2FramingOFDMUsedBandwidth
             (ViSession instrumentHandle, ViPReal64 usedBandwidth);
ViStatus _VI_FUNC rssfc_confDVBT2FramingOFDM (ViSession instrumentHandle,
                                              ViInt32 t2FramesPerSuperFrame,
                                              ViInt32 dataSymbolsPerT2Frame,
                                              ViInt32 subslicesPerT2Frame);
ViStatus _VI_FUNC rssfc_readDVBT2FramingOFDMSymbolsPerT2Frame
             (ViSession instrumentHandle, ViPInt32 OFDMSymbolsPerT2Frame);

ViStatus _VI_FUNC rssfc_ConfigureDVBT2TransmissionSystemNetwork
             (ViSession instrumentHandle, ViInt32 networkMode);

ViStatus _VI_FUNC rssfc_confDVBT2TransmissionSystem (ViSession instrumentHandle,
                                                     ViInt32 networkMode,
                                                     ViInt32 transmissionSystem,
                                                     ViInt32 peakToAvragePowerRatio,
                                                     ViBoolean futureExtensionFrames,
                                                     ViBoolean timeFrequencySlicing);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2MISOGroupMode (ViSession instrumentHandle,
                                                     ViInt32 groupMode);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2TransmissionProfileMode
             (ViSession instrumentHandle, ViInt32 profileMode);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2TransmissionFutureExtensionFrames
             (ViSession instrumentHandle, ViInt32 FEFLength, ViInt32 FEFType,
              ViInt32 FEFInterval);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2TransmissionFutureExtensionPayload
            (ViSession instrumentHandle, ViInt32 FEFPayload);
ViStatus _VI_FUNC rssfc_confDVBT2TransmissionLParam (ViSession instrumentHandle,
                                                     ViInt32 l1T2Version,
                                                     ViInt32 l1PostModulation,
                                                     ViBoolean l1Repetition,
                                                     ViBoolean l1PostExtension,
                                                     ViInt32 numAuxStreams,
                                                     ViBoolean l1RFSignalling);
ViStatus _VI_FUNC rssfc_confDVBT2TransmissionSystemIdentification
             (ViSession instrumentHandle, ViInt32 cellID, ViInt32 networkID,
              ViInt32 systemID, ViUInt16 txIDAvailability);
ViStatus _VI_FUNC rssfc_confDVBT2TransmissionLParametersL1T2
             (ViSession instrumentHandle, ViBoolean l1PostScrambled,
              ViBoolean t2BaseLite);
ViStatus _VI_FUNC rssfc_ReadDVBT2T2SystemL1SignallingFrequency
             (ViSession instrumentHandle, ViPReal64 frequency);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2SFNDelayParameters (ViSession instrumentHandle,
                                                          ViInt32 delayParameter,
                                                          ViReal64 timeValue);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2SFNMuteP1Symbol (ViSession instrumentHandle,
                                                       ViBoolean muteP1SymbolOfSuperFrame);
ViStatus _VI_FUNC rssfc_ReadDVBT2SFNDelayParameters (ViSession instrumentHandle,
                                                     ViInt32 delayParameter,
                                                     ViPReal64 timeValue);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2SFNTimestampOffset (ViSession instrumentHandle,
                                                          ViInt32 timestampOffset);
ViStatus _VI_FUNC rssfc_ConfigureDVBT2SFNUpdateTimestamp
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_ReadDVBT2SFNTimestampMode (ViSession instrumentHandle,
                                                   ViPInt32 timestampMode);
ViStatus _VI_FUNC rssfc_ReadDVBT2SFNTimestampParameters (ViSession instrumentHandle,
                                                         ViPInt32 UTCDate,
                                                         ViPInt32 UTCTime,
                                                         ViPInt32 secondsSince2000);
ViStatus _VI_FUNC rssfc_confDVBT2Settings (ViSession instrumentHandle,
                                           ViInt32 testTSPacket,
                                           ViInt32 payloadTestTSPacket,
                                           ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confATSMInputSignal (ViSession instrumentHandle,
                                             ViInt32 source, ViInt32 input,
                                             ViBoolean stuffing);
ViStatus _VI_FUNC rssfc_confATSMTestSignal (ViSession instrumentHandle,
                                            ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_readATSMPackedLength (ViSession instrumentHandle,
                                              ViPInt32 packedLength);
ViStatus _VI_FUNC rssfc_readATSMValues (ViSession instrumentHandle, ViInt32 value,
                                        ViPReal64 result);
ViStatus _VI_FUNC rssfc_confATSMCoding (ViSession instrumentHandle,
                                        ViReal64 symbolRate, ViBoolean mHState);
ViStatus _VI_FUNC rssfc_ReadATSMConstellation (ViSession instrumentHandle,
                                               ViPInt32 constellation);
ViStatus _VI_FUNC rssfc_ReadATSMRollOff (ViSession instrumentHandle,
                                         ViPReal64 rollOff);
ViStatus _VI_FUNC rssfc_confATSMSettings (ViSession instrumentHandle,
                                          ViInt32 MHEPID, ViBoolean RFWatermark,
                                          ViBoolean MTXIDTransmission,
                                          ViInt32 testTSPacket, ViInt32 payloadTest,
                                          ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confATSMWatermark (ViSession instrumentHandle,
                                           ViInt32 TXAddress, ViInt32 networkID,
                                           ViInt32 buryRatio);
ViStatus _VI_FUNC rssfc_confATSMMTXIDTransmission (ViSession instrumentHandle,
                                                   ViInt32 transmitterID,
                                                   ViInt32 marketID);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2NumberOfPLP (ViSession instrumentHandle,
                                                   ViInt32 numberOfPLP);
ViStatus _VI_FUNC rssfc_configureDVBC2InputSignal (ViSession instrumentHandle,
                                                   ViInt32 PLP, ViInt32 inputFormat,
                                                   ViInt32 source, ViInt32 input);
ViStatus _VI_FUNC rssfc_ReadDVBC2Values (ViSession instrumentHandle, ViInt32 PLP,
                                         ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_ConfigureDVB2CTestSignal (ViSession instrumentHandle,
                                                  ViInt32 PLP, ViInt32 testSignal);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2ModeStreamAdaptation
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 PLPID,
              ViInt32 BBMode, ViInt32 ISSY, ViBoolean nullPacketDel);
ViStatus _VI_FUNC rssfc_ReadDVBC2ModeStreamAdaptationPLPType
             (ViSession instrumentHandle, ViInt32 PLP, ViPInt32 PLPType);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2BICMPLPMappingParameters
             (ViSession instrumentHandle, ViInt32 PLP, ViInt32 FECFrame,
              ViInt32 codeRate, ViInt32 constellation, ViInt32 mapToDSlice);
ViStatus _VI_FUNC rssfc_ReadDVBC2BICMXFECFrameLength (ViSession instrumentHandle,
                                                      ViInt32 PLP,
                                                      ViPInt32 XFECFrameLength);
ViStatus _VI_FUNC rssfc_ReadDVBC2DataSliceMinMax (ViSession instrumentHandle,
                                                  ViPInt32 min_REL_DxTu,
                                                  ViPInt32 max_REL_DxTu,
                                                  ViPInt32 min_ABS_DxTu,
                                                  ViPInt32 max_ABS_DxTu);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2NumberOfDataSlices (ViSession instrumentHandle,
                                                          ViInt32 numberOfDataSlices);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2DataSliceParameters
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 DSliceID_HEX,
              ViInt32 DSliceTIDepth, ViInt32 DSliceType, ViInt32 FECHeaderType,
              ViInt32 numXFECFrames);
ViStatus _VI_FUNC rssfc_ReadDVBC2DataSliceNumPLP (ViSession instrumentHandle,
                                                  ViInt32 DSlice,
                                                  ViPInt32 DSliceNumPLP);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2CurrentDataSliceParameters
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 offsetLeftDxTu,
              ViInt32 tunePos_REL_DxTu, ViInt32 offsetRightDxTu);
ViStatus _VI_FUNC rssfc_ReadDVBC2DataSliceValues (ViSession instrumentHandle,
                                                  ViInt32 DSlice, ViInt32 value,
                                                  ViPInt32 result);
ViStatus _VI_FUNC rssfc_ReadDVBC2DataSliceFrequencyValues
             (ViSession instrumentHandle, ViInt32 DSlice, ViInt32 DSliceValue,
              ViPReal64 result);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2NumberOfNotches (ViSession instrumentHandle,
                                                       ViInt32 numberOfNotches);
ViStatus _VI_FUNC rssfc_ReadDVBC2NumberOfNotches (ViSession instrumentHandle,
                                                  ViPInt32 numberOfNotches);
ViStatus _VI_FUNC rssfc_ReadDVBC2NotchType (ViSession instrumentHandle,
                                            ViInt32 notch, ViPInt32 notchType);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2NotchValues (ViSession instrumentHandle,
                                                   ViInt32 notch,
                                                   ViInt32 start_REL_DxTu,
                                                   ViInt32 stop_REL_DxTu,
                                                   ViInt32 widthDxTu);
ViStatus _VI_FUNC rssfc_ReadDVBC2NotchValues (ViSession instrumentHandle,
                                              ViInt32 notch, ViInt32 value,
                                              ViPInt32 result);
ViStatus _VI_FUNC rssfc_ReadDVBC2NotchFrequencyValues (ViSession instrumentHandle,
                                                       ViInt32 notch,
                                                       ViInt32 notchParameter,
                                                       ViPReal64 result);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2FramingOFDMParameters
             (ViSession instrumentHandle, ViInt32 channelBandwidth,
              ViInt32 numBundledCH, ViInt32 guardInterval);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2FramingOFDMC2Bandwidth
             (ViSession instrumentHandle, ViInt32 c2Bandwidth);
ViStatus _VI_FUNC rssfc_ReadDVBC2FramingOFDMUsedBandwidth
             (ViSession instrumentHandle, ViPReal64 usedBandwidth);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2FramingOFDMBasebandFilter
             (ViSession instrumentHandle, ViInt32 basebandFilter);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2FramingOFDMAdjustRFFrequency
             (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_ReadDVBC2FramingOFDMCalculateCenterFrequency
             (ViSession instrumentHandle, ViPReal64 calculateCenterFrequency);
ViStatus _VI_FUNC rssfc_ReadDVBC2FramingOFDMParameters (ViSession instrumentHandle,
                                                        ViPInt32 DX,
                                                        ViPReal64 carrierSpacing_1Tu,
                                                        ViPInt32 numberOfDataSymbolC2Frame,
                                                        ViPInt32 numberOfPreambleSymbols,
                                                        ViPReal64 startFrequency,
                                                        ViPReal64 calcCenterFrequency);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2C2SystemParameters (ViSession instrumentHandle,
                                                          ViInt32 networkID,
                                                          ViInt32 c2SystemID,
                                                          ViInt32 l1TimeInterleaver,
                                                          ViBoolean systemReservedTones);
ViStatus _VI_FUNC rssfc_ConfigureDVBC2Settings (ViSession instrumentHandle,
                                                ViInt32 testTSPacket,
                                                ViInt32 payloadTestTSPacket,
                                                ViInt32 PRBS);
ViStatus _VI_FUNC rssfc_confAnalogTvVideoInputSignal (ViSession instrumentHandle,
                                                      ViInt32 videoInputSignal);
ViStatus _VI_FUNC rssfc_confAnalogTvVideo (ViSession instrumentHandle,
                                           ViInt32 visionPicture);
ViStatus _VI_FUNC rssfc_loadAnalogTvVideoLibrary (ViSession instrumentHandle,
                                                  ViString loadLibrary);
ViStatus _VI_FUNC rssfc_analogTvVideoLibraryCatalog (ViSession instrumentHandle,
                                                     ViString directory,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR output[],
                                                     ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfc_analogTvVideoLibraryCatalogLength
             (ViSession instrumentHandle, ViString directory,
              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfc_confAnalogTvAudioInputSignal (ViSession instrumentHandle,
                                                      ViInt32 audioInputSignal);
ViStatus _VI_FUNC rssfc_configAnalogTvAudio (ViSession instrumentHandle,
                                             ViInt32 frequencyParameter,
                                             ViReal64 frequencyValue,
                                             ViInt32 levelParameter,
                                             ViReal64 levelValue);
ViStatus _VI_FUNC rssfc_configAnalogTvAudioAf (ViSession instrumentHandle,
                                               ViInt32 audioChannel,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfc_loadAnalogTvAudioLibrary (ViSession instrumentHandle,
                                                  ViString loadLibrary);
ViStatus _VI_FUNC rssfc_analogTvAudioLibraryCatalog (ViSession instrumentHandle,
                                                     ViString directory,
                                                     ViInt32 bufferSize,
                                                     ViChar _VI_FAR output[],
                                                     ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfc_analogTvAudioLibraryCatalogLength
             (ViSession instrumentHandle, ViString directory,
              ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfc_confAnalogTvNICAMSource (ViSession instrumentHandle,
                                                 ViInt32 source,
                                                 ViInt32 NICAMSoundMode);
ViStatus _VI_FUNC rssfc_configAnalogTvNICAMAf (ViSession instrumentHandle,
                                               ViInt32 audioChannel,
                                               ViBoolean state);
ViStatus _VI_FUNC rssfc_configAnalogTvNICAM (ViSession instrumentHandle,
                                             ViInt32 frequencyParameter,
                                             ViReal64 frequencyValue,
                                             ViInt32 levelParameter,
                                             ViReal64 levelValue);
ViStatus _VI_FUNC rssfc_confAnalogTvVideoVisionPicture (ViSession instrumentHandle,
                                                        ViInt32 mode);
ViStatus _VI_FUNC rssfc_readAnalogTvValues (ViSession instrumentHandle,
                                            ViInt32 value, ViPReal64 result);
ViStatus _VI_FUNC rssfc_actEnableAnalogTvSpecial (ViSession instrumentHandle,
                                                  ViBoolean state);
ViStatus _VI_FUNC rssfc_confAnalogTvPreemphasis (ViSession instrumentHandle,
                                                 ViInt32 preemphasis);
ViStatus _VI_FUNC rssfc_confAnalogTvPilot (ViSession instrumentHandle,
                                           ViBoolean pilot,
                                           ViReal64 nomFreqDevPilot);
ViStatus _VI_FUNC rssfc_confAnalogTvSubcarrierSettings (ViSession instrumentHandle,
                                                        ViInt32 subcarrier,
                                                        ViReal64 nomFreqDev,
                                                        ViBoolean subcarrierState,
                                                        ViReal64 frequencySubcarrier,
                                                        ViReal64 levelSubcarrier);
ViStatus _VI_FUNC rssfc_confAnalogTvSpecialSettings (ViSession instrumentHandle,
                                                     ViBoolean VSBFilter,
                                                     ViBoolean GDPrecorrection,
                                                     ViReal64 residualCarrier);
ViStatus _VI_FUNC rssfc_confAnalogTvSpecialVideoCarrier (ViSession instrumentHandle,
                                                         ViBoolean video,
                                                         ViBoolean carrier);
ViStatus _VI_FUNC rssfc_confAnalogTvSpecialVsbCharacteristic
             (ViSession instrumentHandle, ViInt32 VSBCharacteristic);
ViStatus _VI_FUNC rssfc_setAnalogTvSpecialAmModulationDepth
             (ViSession instrumentHandle, ViInt32 AMModulationDepth);
ViStatus _VI_FUNC rssfc_confAnalogTvSpecialNICAM (ViSession instrumentHandle,
                                                  ViBoolean preemphasis,
                                                  ViInt32 rollOff,
                                                  ViReal64 gainAdjustAF1,
                                                  ViReal64 gainAdjustAF2);
ViStatus _VI_FUNC rssfc_configAudioBCFMInputSignal (ViSession instrumentHandle,
                                                    ViInt32 sourceLeft,
                                                    ViInt32 sourceRight,
                                                    ViInt32 AFMode);
ViStatus _VI_FUNC rssfc_confAudioBCFMSource (ViSession instrumentHandle,
                                             ViInt32 source, ViReal64 frequency,
                                             ViReal64 level);
ViStatus _VI_FUNC rssfc_configAudioBCFMRDSRBDS (ViSession instrumentHandle,
                                                ViString groupSequence,
                                                ViInt32 programIdentification,
                                                ViString PS, ViBoolean TP,
                                                ViBoolean TA, ViInt32 PTY,
                                                ViString PTYN, ViString RT,
                                                ViInt32 MS);
ViStatus _VI_FUNC rssfc_ReadAudioBCFMRDSRBDSRadioTextStatus
             (ViSession instrumentHandle, ViPInt32 RTReady);
ViStatus _VI_FUNC rssfc_configAudioBCFMRDSRBDSDecoderIdn (ViSession instrumentHandle,
                                                          ViBoolean DIDynamicPTY,
                                                          ViBoolean DICompressed,
                                                          ViBoolean DIArtHead,
                                                          ViBoolean DIStereo,
                                                          ViBoolean CT,
                                                          ViString CTOffset,
                                                          ViInt32 AFMethod);
ViStatus _VI_FUNC rssfc_SetAudioBCFMAFAFreq (ViSession instrumentHandle,
                                             ViInt32 numberOfFreq);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCFMAFAFrequency (ViSession instrumentHandle,
                                                        ViInt32 AF,
                                                        ViReal64 frequency);
ViStatus _VI_FUNC rssfc_SetAudioBCFMAFBList (ViSession instrumentHandle,
                                             ViInt32 numberOfLists);
ViStatus _VI_FUNC rssfc_SetAudioBCFMAFBFreq (ViSession instrumentHandle,
                                             ViInt32 list, ViInt32 numberOfFreq,
                                             ViReal64 tuningFreq);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCFMAFBFrequency (ViSession instrumentHandle,
                                                        ViInt32 list, ViInt32 AF,
                                                        ViReal64 frequency,
                                                        ViInt32 order);
ViStatus _VI_FUNC rssfc_configAudioBCFMEONParameters (ViSession instrumentHandle,
                                                      ViInt32 EONPI, ViString EONPS,
                                                      ViBoolean EONTP,
                                                      ViBoolean EONTA,
                                                      ViBoolean EONLA,
                                                      ViBoolean EONEG,
                                                      ViBoolean EONILS,
                                                      ViInt32 EONLSN,
                                                      ViInt32 EONPTY,
                                                      ViInt32 EONPIN,
                                                      ViInt32 EONAFMethod);
ViStatus _VI_FUNC rssfc_SetAudioBCFMEONAFAFreq (ViSession instrumentHandle,
                                                ViInt32 numberOfFreq);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCFMEONAFAFrequency
             (ViSession instrumentHandle, ViInt32 AF, ViReal64 frequency);
ViStatus _VI_FUNC rssfc_SetAudioBCFMEONAFMappedFreqNumberOfFreq
             (ViSession instrumentHandle, ViInt32 numberOfFreq,
              ViReal64 tuningFreq);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCFMEONAFMappedFrequency
             (ViSession instrumentHandle, ViInt32 AF, ViReal64 frequency);
ViStatus _VI_FUNC rssfc_EnableAudioBCFMTMC (ViSession instrumentHandle,
                                            ViBoolean TMC);
ViStatus _VI_FUNC rssfc_AudioBCFMTMCSendData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_SetAudioBCTMCGroup3AVARParameters
             (ViSession instrumentHandle, ViInt32 group3AVAR00,
              ViInt32 group3AVAR01);
ViStatus _VI_FUNC rssfc_SetAudioBCTMCNumberOf8AGroups (ViSession instrumentHandle,
                                                       ViInt32 numberOf8AGroups);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCFMTMC8ABlock (ViSession instrumentHandle,
                                                      ViInt32 group8A,
                                                      ViInt32 block, ViInt32 value);
ViStatus _VI_FUNC rssfc_EnableAudioBCFMOpenFormat (ViSession instrumentHandle,
                                                   ViBoolean openFormat);
ViStatus _VI_FUNC rssfc_AudioBCFMOpenFormatSendData (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCOpenFormatGroupA (ViSession instrumentHandle,
                                                          ViInt32 groupA,
                                                          ViInt32 block,
                                                          ViInt32 value);
ViStatus _VI_FUNC rssfc_ConfigureAudioBCOpenFormatGroupB (ViSession instrumentHandle,
                                                          ViInt32 groupB,
                                                          ViInt32 block,
                                                          ViInt32 value);
ViStatus _VI_FUNC rssfc_AudioBCOpenFormatGroupDataTransferStatus
             (ViSession instrumentHandle, ViInt32 group, ViInt32 groupType,
              ViPInt32 transferStatus);
ViStatus _VI_FUNC rssfc_configAudioBCFMAudioModulation (ViSession instrumentHandle,
                                                        ViInt32 mode,
                                                        ViInt32 preemphasis,
                                                        ViReal64 nomFreqDevAudio);
ViStatus _VI_FUNC rssfc_configureAudioBCModulationRDS (ViSession instrumentHandle,
                                                       ViBoolean RDS,
                                                       ViReal64 freqDevRDS,
                                                       ViReal64 freqDevPilot19KHz);
ViStatus _VI_FUNC rssfc_readAudioBCFMModulationValues (ViSession instrumentHandle,
                                                       ViInt32 value,
                                                       ViPReal64 result);
ViStatus _VI_FUNC rssfc_enableAudioBCFMSpecialSettings (ViSession instrumentHandle,
                                                        ViBoolean state);
ViStatus _VI_FUNC rssfc_confAudioBCFMSpecialSettings (ViSession instrumentHandle,
                                                      ViBoolean pilot,
                                                      ViReal64 phaseOffsetPilot19kHz,
                                                      ViReal64 phaseOffsetRDS);
ViStatus _VI_FUNC rssfc_configAudioBCAMInputSignal (ViSession instrumentHandle,
                                                    ViInt32 source);
ViStatus _VI_FUNC rssfc_confAudioBCAMSource (ViSession instrumentHandle,
                                             ViReal64 frequency, ViReal64 level);
ViStatus _VI_FUNC rssfc_confAudioBCAMModulationDepth (ViSession instrumentHandle,
                                                      ViReal64 nomModDepth);
ViStatus _VI_FUNC rssfc_readAudioBCAMModeDepth (ViSession instrumentHandle,
                                                ViPReal64 modeDepth);
ViStatus _VI_FUNC rssfc_NoiseConfiguration (ViSession instrumentHandle,
                                            ViInt32 noise, ViReal64 cN,
                                            ViBoolean bandwidthCoupling,
                                            ViReal64 receiverBandwidth);
ViStatus _VI_FUNC rssfc_readNoiseGenBand (ViSession instrumentHandle,
                                          ViPReal64 generatedNoiseBandwidth);
ViStatus _VI_FUNC rssfc_confNoiseCn (ViSession instrumentHandle, ViReal64 cN);
ViStatus _VI_FUNC rssfc_readNoiseCN (ViSession instrumentHandle, ViPReal64 cN);
ViStatus _VI_FUNC rssfc_readNoiseGenState (ViSession instrumentHandle,
                                           ViPInt32 noiseState);
ViStatus _VI_FUNC rssfc_readTsgenStatus (ViSession instrumentHandle,
                                         ViPInt32 command);
ViStatus _VI_FUNC rssfc_actFileOperations (ViSession instrumentHandle,
                                           ViInt32 operationToBePerformed,
                                           ViString source, ViString destination);
ViStatus _VI_FUNC rssfc_actFileCatPath (ViSession instrumentHandle, ViInt32 read,
                                        ViString directory, ViInt32 bufferSize,
                                        ViChar _VI_FAR output[],
                                        ViPInt32 returnedValues);
ViStatus _VI_FUNC rssfc_readCatalogLength (ViSession instrumentHandle, ViInt32 read,
                                           ViPInt32 catalogLength);
ViStatus _VI_FUNC rssfc_confTsgenPlayfile (ViSession instrumentHandle,
                                           ViString load);
ViStatus _VI_FUNC rssfc_setTsByteRate (ViSession instrumentHandle,
                                       ViReal64 byteRate);
ViStatus _VI_FUNC rssfc_readTsgenPlayerParam (ViSession instrumentHandle,
                                              ViChar _VI_FAR fileDateSize[],
                                              ViChar _VI_FAR originalLoopTime[],
                                              ViPReal64 originalTSDataRate);
ViStatus _VI_FUNC rssfc_actTsgenStatus (ViSession instrumentHandle,
                                        ViInt32 command);
ViStatus _VI_FUNC rssfc_confTsgenTimingSettings (ViSession instrumentHandle,
                                                 ViReal64 TSDataRate,
                                                 ViReal64 playWindowStart,
                                                 ViReal64 playWindowStop);
ViStatus _VI_FUNC rssfc_ReadTSDataRate (ViSession instrumentHandle,
                                        ViPReal64 TSDataRate);
ViStatus _VI_FUNC rssfc_TSGenNullpacketStuffing (ViSession instrumentHandle,
                                                 ViBoolean nullpacketStuffing);
ViStatus _VI_FUNC rssfc_TSGenPackedLength (ViSession instrumentHandle,
                                           ViPInt32 packetLength);
ViStatus _VI_FUNC rssfc_readTSGenSeekPosition (ViSession instrumentHandle,
                                               ViPReal64 position);
ViStatus _VI_FUNC rssfc_TSGenConfigureSeamlessLoop (ViSession instrumentHandle,
                                                    ViBoolean continuityCounter,
                                                    ViBoolean PCRDTSPTS,
                                                    ViBoolean TDTTOT);
ViStatus _VI_FUNC rssfc_confCalInternal (ViSession instrumentHandle,
                                         ViBoolean internalLevelCorrection);
ViStatus _VI_FUNC rssfc_actCal (ViSession instrumentHandle, ViInt32 calibrationType,
                                ViPInt32 result);
ViStatus _VI_FUNC rssfc_getCalDate (ViSession instrumentHandle,
                                    ViInt32 calibrationType, ViChar _VI_FAR datum[]);
ViStatus _VI_FUNC rssfc_systemDisplayUpdate (ViSession instrumentHandle,
                                             ViBoolean displayUpdate);
ViStatus _VI_FUNC rssfc_systemKeypadLock (ViSession instrumentHandle,
                                          ViInt32 keypadLock);
ViStatus _VI_FUNC rssfc_setStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 enable, ViInt32 PTransition,
                                           ViInt32 NTransition);
ViStatus _VI_FUNC rssfc_getStatusRegister (ViSession instrumentHandle,
                                           ViInt32 registerOperation,
                                           ViInt32 statusRegistersQuery,
                                           ViPInt32 registerValue);
ViStatus _VI_FUNC rssfc_setUserDefStatusRegister (ViSession instrumentHandle,
                                                  ViInt32 registerOperation,
                                                  ViInt32 userdefinableBit,
                                                  ViInt32 enable,
                                                  ViInt32 PTransition,
                                                  ViInt32 NTransition);
ViStatus _VI_FUNC rssfc_getUserDefStatusRegister (ViSession instrumentHandle,
                                                  ViInt32 registerOperation,
                                                  ViInt32 userdefinableBit,
                                                  ViInt32 statusRegistersQuery,
                                                  ViPInt32 registerValue);
ViStatus _VI_FUNC rssfc_confReferenceOscillator (ViSession instrumentHandle,
                                                 ViInt32 source,
                                                 ViBoolean adjustmentState,
                                                 ViInt32 adjustmentFrequency);
ViStatus _VI_FUNC rssfc_SetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViInt32 attributeValue);
ViStatus _VI_FUNC rssfc_SetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViReal64 attributeValue);
ViStatus _VI_FUNC rssfc_SetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViString attributeValue);
ViStatus _VI_FUNC rssfc_SetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViBoolean attributeValue);
ViStatus _VI_FUNC rssfc_SetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViSession attributeValue);
ViStatus _VI_FUNC rssfc_GetAttributeViInt32 (ViSession instrumentHandle,
                                             ViString repeatedCapabilityName,
                                             ViUInt32 attributeID,
                                             ViPInt32 attributeValue);
ViStatus _VI_FUNC rssfc_GetAttributeViReal64 (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViPReal64 attributeValue);
ViStatus _VI_FUNC rssfc_GetAttributeViString (ViSession instrumentHandle,
                                              ViString repeatedCapabilityName,
                                              ViUInt32 attributeID,
                                              ViInt32 bufferSize,
                                              ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rssfc_GetAttributeViBoolean (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPBoolean attributeValue);
ViStatus _VI_FUNC rssfc_GetAttributeViSession (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViPSession attributeValue);
ViStatus _VI_FUNC rssfc_CheckAttributeViInt32 (ViSession instrumentHandle,
                                               ViString repeatedCapabilityName,
                                               ViUInt32 attributeID,
                                               ViInt32 attributeValue);
ViStatus _VI_FUNC rssfc_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViReal64 attributeValue);
ViStatus _VI_FUNC rssfc_CheckAttributeViString (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViString attributeValue);
ViStatus _VI_FUNC rssfc_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViBoolean attributeValue);
ViStatus _VI_FUNC rssfc_CheckAttributeViSession (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViSession attributeValue);
ViStatus _VI_FUNC rssfc_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rssfc_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rssfc_storeLoadApplication (ViSession instrumentHandle,
                                              ViInt32 operation, ViString source);
ViStatus _VI_FUNC rssfc_storeLoadInstrumentData (ViSession instrumentHandle,
                                                 ViInt32 networkMode,
                                                 ViInt32 stateNumber);
ViStatus _VI_FUNC rssfc_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_ResetWithDefaults (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_Disable (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_self_test (ViSession instrumentHandle,
                                   ViPInt16 selfTestResult,
                                   ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssfc_revision_query (ViSession instrumentHandle,
                                        ViChar _VI_FAR instrumentDriverRevision[],
                                        ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssfc_error_query (ViSession instrumentHandle, ViPInt32 errorCode,
                                     ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssfc_error_message (ViSession instrumentHandle,
                                       ViStatus errorCode,
                                       ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssfc_readToFile (ViSession instrumentHandle, ViString source,
                                    ViString destination);
ViStatus _VI_FUNC rssfc_writeFromFile (ViSession instrumentHandle, ViString source,
                                       ViString destination);
ViStatus _VI_FUNC rssfc_SetOPCTimeout (ViSession instrumentHandle, ViInt32 timeout);
ViStatus _VI_FUNC rssfc_GetOPCTimeout (ViSession instrumentHandle,
                                       ViPInt32 timeout);
ViStatus _VI_FUNC rssfc_GetError (ViSession instrumentHandle, ViPStatus code,
                                  ViInt32 bufferSize, ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rssfc_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rssfc_LockSession (ViSession instrumentHandle,
                                     ViPBoolean callerHasLock);
ViStatus _VI_FUNC rssfc_UnlockSession (ViSession instrumentHandle,
                                       ViPBoolean callerHasLock);
ViStatus _VI_FUNC rssfc_WriteInstrData (ViSession instrumentHandle,
                                        ViString writeBuffer);
ViStatus _VI_FUNC rssfc_ReadInstrData (ViSession instrumentHandle,
                                       ViInt32 numberOfBytesToRead,
                                       ViChar _VI_FAR readBuffer[],
                                       ViPInt32 numBytesRead);
ViStatus _VI_FUNC rssfc_close (ViSession instrumentHandle);




/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSSFC_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSSFC_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSSFC_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE (RS_CLASS_ERROR_BASE + 0x0004L) 
#define RSSFC_ERROR_MARKER_NOT_ENABLED     (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSSFC_ERROR_NOT_DELTA_MARKER       (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSSFC_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSSFC_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSSFC_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSSFC_ERRMSG_MARKER_NOT_ENABLED    "Marker Not Enabled"
#define RSSFC_ERRMSG_NOT_DELTA_MARKER      "Not Delta Marker"
#define RSSFC_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSSFC_ERROR_CODES_AND_MSGS \
    {RSSFC_WARN_MEASURE_UNCALIBRATED,  RSSFC_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSSFC_WARN_OVER_RANGE,            RSSFC_WARNMSG_OVER_RANGE},\
    {RSSFC_ERROR_MARKER_NOT_ENABLED,   RSSFC_ERRMSG_MARKER_NOT_ENABLED},\
    {RSSFC_ERROR_NOT_DELTA_MARKER,     RSSFC_ERRMSG_NOT_DELTA_MARKER},\
    {RSSFC_ERROR_MAX_TIME_EXCEEDED,    RSSFC_ERRMSG_MAX_TIME_EXCEEDED}

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
    

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSSFC_HEADER */
